/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: kleber $
 *  Last update : $Date: 2000/03/13 14:39:52 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package browser;

import java.lang.*;
import javax.swing.tree.*;
import javax.swing.*;
import java.awt.*;
import jToolkit.io.*;
import main.MainContext;

/**
 * Draws a tree element with the correct icon in the tree 
 * 
 * @author Andreas Schroeter
 * @since 30.04.1999
*/
public class MyTreeCellRenderer implements TreeCellRenderer
{
      // Icons
      
    /** 
     * Icon used to show nodes as Presentation State.
    */
    transient protected Icon PSIcon;
      
    /** 
     * Icon used to show nodes as Study.
    */
    transient protected Icon StudyIcon;
    
    /** 
     * Icon used to show nodes as Series.
    */
    transient protected Icon SeriesIcon;
    
    /** 
     * Icon used to show nodes as Instance.
    */
    transient protected Icon InstanceIcon;
    
    /** 
     * Icon used to show nodes as default.
    */
    transient protected Icon defaultIcon;
    
    /** 
     * Icon used to show nodes as new Entry.
    */
    transient protected Icon newIcon;
    
    /** 
     * Icon used to show nodes as new Entry.
    */
    transient protected Icon hcIcon;
    /** 
     * Icon used to show nodes as new Entry.
    */
    transient protected Icon spIcon;
    // ----------------
      
    /** Icon used to show non-leaf nodes that aren't expanded. */
    transient protected Icon closedIcon;

    /** Icon used to show leaf nodes. */
    transient protected Icon leafIcon;

    /** Icon used to show non-leaf nodes that are expanded. */
    transient protected Icon openIcon;

     // Colors
    /** Color to use for the foreground for selected nodes. */
    protected Color textSelectionColor;

    /** Color to use for the foreground for non-selected nodes. */
    protected Color textNonSelectionColor;

    /** Color to use for the background when a node is selected. */
    protected Color backgroundSelectionColor;

    /** Color to use for the background when the node isn't selected. */
    protected Color backgroundNonSelectionColor;

    /** Color to use for the background when the node isn't selected. */
    protected Color borderSelectionColor;

    protected JLabel label=new JLabel();

    protected Font textSelectionFont;
    protected Font textNonSelectionFont;


    public MyTreeCellRenderer()
    {
        label.setOpaque(true);
        Font f=label.getFont();
	  IconRetriever ir = new IconRetriever();        


        if (MainContext.instance().highQualitySystem)
        {
            textSelectionFont=new Font(f.getName(), f.getStyle() | Font.ITALIC, f.getSize());
            textNonSelectionFont=new Font(f.getName(), f.getStyle(), f.getSize());
            
            PSIcon = ir.getIcon (MainContext.iconPath + "bigps.gif"); 
            //new ImageIcon (MainContext.iconPath + "bigps.gif");

            InstanceIcon = ir.getIcon (MainContext.iconPath + "biginstance.gif");
            SeriesIcon = ir.getIcon (MainContext.iconPath + "bigseries.gif");
            StudyIcon = ir.getIcon (MainContext.iconPath + "bigstudy.gif");        
            defaultIcon = ir.getIcon (MainContext.iconPath + "bigdefault.gif");
            newIcon = ir.getIcon (MainContext.iconPath + "bignew.gif");
            hcIcon = ir.getIcon (MainContext.iconPath + "hc32.gif");
            spIcon = ir.getIcon (MainContext.iconPath + "sp32.gif");
            /*
            InstanceIcon = new ImageIcon (MainContext.iconPath + "biginstance.gif");
            SeriesIcon = new ImageIcon (MainContext.iconPath + "bigseries.gif");
            StudyIcon = new ImageIcon (MainContext.iconPath + "bigstudy.gif");        
            defaultIcon = new ImageIcon (MainContext.iconPath + "bigdefault.gif");
            newIcon = new ImageIcon (MainContext.iconPath + "bignew.gif");
            hcIcon = new ImageIcon (MainContext.iconPath + "hc32.gif");
            spIcon = new ImageIcon (MainContext.iconPath + "sp32.gif");
*/
        }
        else
        {
            textSelectionFont=new Font(f.getName(),f.getStyle()|Font.ITALIC,f.getSize());
            textNonSelectionFont=f;

            PSIcon = ir.getIcon (MainContext.iconPath + "ps.gif");
            InstanceIcon = ir.getIcon(MainContext.iconPath + "instance.gif");
            SeriesIcon = ir.getIcon (MainContext.iconPath + "series.gif");
            StudyIcon = ir.getIcon (MainContext.iconPath + "study.gif");        
            defaultIcon = ir.getIcon(MainContext.iconPath + "default.gif");
            newIcon = ir.getIcon (MainContext.iconPath + "new.gif");
            hcIcon = ir.getIcon (MainContext.iconPath + "hc.gif");
            spIcon = ir.getIcon (MainContext.iconPath + "sp.gif");

/*
		PSIcon = new ImageIcon (MainContext.iconPath + "ps.gif");
            InstanceIcon = new ImageIcon (MainContext.iconPath + "instance.gif");
            SeriesIcon = new ImageIcon (MainContext.iconPath + "series.gif");
            StudyIcon = new ImageIcon (MainContext.iconPath + "study.gif");        
            defaultIcon = new ImageIcon (MainContext.iconPath + "default.gif");
            newIcon = new ImageIcon (MainContext.iconPath + "new.gif");
            hcIcon = new ImageIcon (MainContext.iconPath + "hc.gif");
            spIcon = new ImageIcon (MainContext.iconPath + "sp.gif");
*/
        }
        setTextSelectionColor(UIManager.getColor("Tree.textSelectionColor"));
        setTextNonSelectionColor(UIManager.getColor("Tree.textNonSelectionColor"));
        setBackgroundSelectionColor(UIManager.getColor("Tree.selectionBackground"));
        setBackgroundNonSelectionColor(UIManager.getColor("Tree.backgroundNonSelectionColor"));
        setBorderSelectionColor(UIManager.getColor("Tree.borderSelectionColor"));
    }

    /**
     * Returns the default icon used to represent non-leaf nodes that are expanded.
    */
    public Icon getDefaultOpenIcon() 
    { 
        return openIcon;
    }

    /**
     * Returns the default icon used to represent non-leaf nodes that are not
     * expanded.
    */
    public Icon getDefaultClosedIcon() 
    {
        return closedIcon;
    }

    /**
     * Returns the default icon used to represent leaf nodes.
    */
    public Icon getDefaultLeafIcon() 
    {
        return leafIcon;
    }

    /**
     * Sets the icon used to represent non-leaf nodes that are expanded.
    */
    public void setOpenIcon(Icon newIcon) 
    {
        openIcon = newIcon;
    }

    /**
     * Returns the icon used to represent non-leaf nodes that are expanded.
    */
    public Icon getOpenIcon() 
    {
        return openIcon;
    }

    /**
     * Sets the icon used to represent non-leaf nodes that are not expanded.
    */
    public void setClosedIcon(Icon newIcon) 
    {
        closedIcon = newIcon;
    }

    /**
     * Returns the icon used to represent non-leaf nodes that are not
     * expanded.
    */
    public Icon getClosedIcon() 
    {
        return closedIcon;
    }

    /**
     * Sets the icon used to represent leaf nodes.
    */
    public void setLeafIcon(Icon newIcon) 
    {
        leafIcon = newIcon;
    }

    /**
     * Returns the icon used to represent leaf nodes.
    */
    public Icon getLeafIcon() 
    {
        return leafIcon;
    }
    
    /**
     * Sets the color the text is drawn with when the node is selected.
    */
    public void setTextSelectionColor(Color newColor) 
    {
        textSelectionColor = newColor;
    }

    /**
     * Returns the color the text is drawn with when the node is selected.
    */
    public Color getTextSelectionColor() 
    {
        return textSelectionColor;
    }

    /**
     * Sets the color the text is drawn with when the node isn't selected.
    */
    public void setTextNonSelectionColor(Color newColor) 
    {
        textNonSelectionColor = newColor;
    }

    /**
     * Returns the color the text is drawn with when the node isn't selected.
    */
    public Color getTextNonSelectionColor() 
    {
        return textNonSelectionColor;
    }

    /**
     * Sets the color to use for the background if node is selected.
    */
    public void setBackgroundSelectionColor(Color newColor) 
    {
        backgroundSelectionColor = newColor;
    }


    /**
     * Returns the color to use for the background if node is selected.
    */
    public Color getBackgroundSelectionColor() 
    {
        return backgroundSelectionColor;
    }

    /**
     * Sets the background color to be used for non selected nodes.
    */
    public void setBackgroundNonSelectionColor(Color newColor) 
    {
        backgroundNonSelectionColor = newColor;
    }

    /**
     * Returns the background color to be used for non selected nodes.
    */
    public Color getBackgroundNonSelectionColor() 
    {
        return backgroundNonSelectionColor;
    }

    /**
     * Sets the color to use for the border.
    */
    public void setBorderSelectionColor(Color newColor) 
    {
        borderSelectionColor = newColor;
    }

    /**
      * Returns the color the border is drawn.
      */
    public Color getBorderSelectionColor() 
    {
        return borderSelectionColor;
    }

    /**
     * Renders the Component.
    */
    public Component getTreeCellRendererComponent(JTree tree, Object value, boolean selected, 
                                                  boolean expanded, boolean leaf, int row, 
                                                  boolean hasFocus)
    {
        DefaultMutableTreeNode node=(DefaultMutableTreeNode)value;
        Object userObject=node.getUserObject();        
        TreeElement te = (TreeElement) userObject;
        
        
        if(selected)
        {
            label.setForeground(getTextSelectionColor());
            label.setBackground(getBackgroundSelectionColor());
            label.setFont(textSelectionFont);
        }
        else
        {
            label.setForeground(getTextNonSelectionColor());
            label.setBackground(getBackgroundNonSelectionColor());
            label.setFont(textNonSelectionFont);
        }
        
        label.setText(te.toString());
        label.setToolTipText(te.toString());
        
        

        if (TreeElement.showNewWithIcon && te.isNew() && te.studyIdx != -1) label.setIcon (newIcon);
        else 
            if (te.isPS()) label.setIcon (PSIcon);
	    else if (te.Modality.equals("HC")&&(te.instanceIdx != -1)) label.setIcon(hcIcon);
	    else if (te.Modality.equals("SP")&&(te.instanceIdx != -1)) label.setIcon(spIcon);
	    
	    else if (te.instanceIdx != -1) label.setIcon (InstanceIcon);
	    else if (te.seriesIdx != -1) label.setIcon (SeriesIcon);
	    else if (te.studyIdx != -1) label.setIcon (StudyIcon);
	    else label.setIcon (defaultIcon);
        Dimension di=label.getMinimumSize();
        di.width+=16;
        di.height+=1;
        label.setPreferredSize(di);
        
        return label;
    }
}

/*
 *  CVS Log
 *  $Log: MyTreeCellRenderer.java,v $
 *  Revision 1.1.1.1  2000/03/13 14:39:52  kleber
 *  init log for first free release
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
