/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: kleber $
 *  Last update : $Date: 2000/03/17 14:07:55 $
 *  Revision :    $Revision: 1.2 $
 *  State:        $State: Exp $
*/

package browser;
 

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.tree.*;

import J2Ci.*;
import DICOMscope;
import viewer.main.*;
import main.MainContext;
import jToolkit.gui.*;
import main.*;
import java.io.*;
import java.util.*;
/**
 * This class contains the study browser. A tree shows the study/series/instance 
 * information hierarchically. The user can modify the shown information with
 * checkboxes on the bottom left corner. Instances or presentation states
 * can be loaded with a double-click on an list entry or with selecting and using the 
 * "Load"-button (the viewer will be shown automatically). 
 * They can also be sent to other workstations with the "Sent-To"-button.
 * Further, studies/series/instances (and Presentation states) can be deleted.
 * 
 * @author Andreas Schroeter
 * @since 30.04.1999
 */
public class StudyMan extends JPanel implements MainListener
{
    /** The Interface class */
    protected jDVInterface dvi;
    
    /** The tree containing all study data */
    JTree tree;
    
    /** root element of the tree */
    DefaultMutableTreeNode root;
    
    /** Instance of the Frame class */
    DICOMscope parentF;
    
    
    /** Thread to update the tree after recieving instances */
    UpdateThread ut;
    
    /** is the database locked? */
    boolean DBlocked = false;
    
    /** pause the update-thread? */
    public boolean suspendThread = false;
    
    /** show contents for high-quality system */
    boolean highQualityScreen = false;
    
    /** save the folder where an image was loaded from */
    File oldLoadFileDir = null;
    
    /** an instance of this class */
    public static StudyMan instance = null; // halbes singleton...
        
    public String fileN;
    JPanel buttonPanel = new JPanel ();		
    
    private boolean buttonsOn = false;
    /**
     * constructor, sets up the panel
     * 
     * @param dvi           the Interface to the DICOMtoolkit
     * @param parent        parent frame
     * @param viewInterface reference to the viewer
     * @param sl            reference to the statusbar
     * @since 30.03
     */
	public StudyMan(jDVInterface dvi, DICOMscope parent,Hashtable config)	
	{	    
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		super();
		Controller.instance().addMainListener(this);
		setLayout(new BorderLayout(5,5));
		StudyMan.instance = this;
		
       
        //oldLoadFileDir = new File(mc.getMainDirectory());
		
		JPanel cp = new JPanel (new GridLayout(2, 4, 0, 0));
		    
		
		cp.add (patiCb);
		cp.add (timeCb);
		cp.add (newiCb);
		cp.add (fileCb);
		cp.add (modaCb);		
		cp.add (descCb);
		cp.add (uidCb);
		cp.add (lablCb);
		
		
		buttonPanel.add (cp);
		
		buttonPanel.add (new JLabel ("      "));
		
		JPanel p2 = new JPanel (new GridLayout(2,2,5,5));
		
		loadBt.setText("Load");
		loadBt.setBackground(java.awt.Color.lightGray);
		loadBt.setBounds(24,264,108,24);		
		p2.add(loadBt);
		
		sendBt.setText("Send To");
		sendBt.setBackground(java.awt.Color.lightGray);
		sendBt.setBounds(24,264,108,24);		
		p2.add(sendBt);				
	
		deleteBt.setText("Delete");
		deleteBt.setBackground(java.awt.Color.lightGray);
		deleteBt.setBounds(24,264,108,24);		
		p2.add(deleteBt);
    
    	loadfileBt.setText("Load File...");
		loadfileBt.setBackground(java.awt.Color.lightGray);
		loadfileBt.setBounds(24,264,108,24);		
		p2.add(loadfileBt);
		
		refreshBt.setText("Refresh");
		refreshBt.setBackground(java.awt.Color.lightGray);
		refreshBt.setBounds(24,264,108,24);		
		p2.add(refreshBt);
		
		exitBt.setText("Exit");
		exitBt.setBackground(java.awt.Color.lightGray);
		exitBt.setBounds(24,264,108,24);		
		p2.add(exitBt);
		
		buttonPanel.add (p2);
		
		//}}
		
		root = new DefaultMutableTreeNode (new TreeElement ("All Studies"));
		tree = new JTree (root);
		
		tree.setRootVisible(true);		
		tree.setShowsRootHandles(true);		
		tree.getSelectionModel().setSelectionMode (TreeSelectionModel.SINGLE_TREE_SELECTION);
		tree.putClientProperty("JTree.lineStyle", "Angled"); // Linien zwischen Knoten
				
		MyTreeCellRenderer renderer = new MyTreeCellRenderer();
		tree.setCellRenderer(renderer);
        
        MouseListener ml = new MouseAdapter() // load Image on double-click!
        {
            public void mouseClicked(MouseEvent e) 
            {
                int selRow = tree.getRowForLocation(e.getX(), e.getY());
                TreePath selPath = tree.getPathForLocation(e.getX(), e.getY());
                if(selRow != -1) 
                {
                    if(e.getClickCount() == 2) 
                    {                        
                        OnLoad ();
                    }
                }
            }
        };
        tree.addMouseListener(ml);        
        
		add("Center", new JScrollPane(tree));
		
		this.dvi = dvi;
       setConfiguaration (config, true);
		//{{INIT_MENUS
		//}}

        parentF = parent;

		//{{REGISTER_LISTENERS
		SymAction lSymAction = new SymAction();
		loadBt.addActionListener(lSymAction);
		//loadfileBt.addActionListener(lSymAction);
		sendBt.addActionListener(lSymAction);
		refreshBt.addActionListener(lSymAction);
		//exitBt.addActionListener(lSymAction);		
		deleteBt.addActionListener(lSymAction);		
		uidCb.addActionListener(lSymAction);
		patiCb.addActionListener(lSymAction);
		descCb.addActionListener(lSymAction);
		modaCb.addActionListener(lSymAction);
		newiCb.addActionListener(lSymAction);
		timeCb.addActionListener(lSymAction);
		fileCb.addActionListener(lSymAction);
		lablCb.addActionListener(lSymAction);
		//}}
		
		parent.setVisible(true);
		parent.addNotify();
		
    	LoadAll(true);
    	
    	// remove line later!!! or not. :)
    	boolean dummy = dvi.newInstancesReceived(); // wegen ersten Return-Wert (immer true)
    	
    	
    	
	}



	//{{DECLARE_CONTROLS
	JButton loadBt = new JButton ();
    JButton sendBt = new JButton ();
    JButton deleteBt = new JButton ();
    JButton exitBt = new JButton ();
    JButton loadfileBt = new JButton ();
    JButton refreshBt = new JButton ();
    
    JCheckBox uidCb = new JCheckBox("UID", false);
    JCheckBox descCb = new JCheckBox("Descr.", true);
    JCheckBox patiCb = new JCheckBox("Pat. Info", true);
    JCheckBox modaCb = new JCheckBox("Modality", true);
    JCheckBox timeCb = new JCheckBox("Date&Time", true);
    JCheckBox newiCb = new JCheckBox("New Items", true);
    JCheckBox fileCb = new JCheckBox("Filename", false);
    JCheckBox lablCb = new JCheckBox("Label", false);
	//}}
	

	//{{DECLARE_MENUS
	//}}

	/**
	 * called after the tree model has changed to update the view
	 * 
	 * @since 30.03
	 */
	void TreeChanged ()
	{
	    TreeElement.showUID = uidCb.isSelected ();
        TreeElement.showPatientInfo = patiCb.isSelected();
        TreeElement.showModality = modaCb.isSelected();
        TreeElement.showDescription = descCb.isSelected();
        TreeElement.showNewWithIcon = newiCb.isSelected();
        TreeElement.showDateTime = timeCb.isSelected();
        TreeElement.showFilename = fileCb.isSelected();
        TreeElement.showLabel = lablCb.isSelected();
        
	    // update Tree elements
	    DefaultTreeModel treemodel = (DefaultTreeModel) tree.getModel();
	    int n = tree.getRowCount();	    
	    	    
	    for (int i = 0; i < n; i++)
	    {
	        TreePath tp = tree.getPathForRow(i);
	        DefaultMutableTreeNode dm = (DefaultMutableTreeNode) tp.getLastPathComponent();
	        treemodel.nodeChanged(dm);	    
	    }	    
	}
	
	
	/**
	 * Loads the Studies, series and instances.
	 * 
	 * @param reloadAll true to load new and old element, false to load only new element.
	 * @since 30.03
	 */
	public void LoadAll (boolean reloadAll)
	{	
	    DBlocked = true;
	    
	    suspendThread = true;
	    
	    int nrOfStudies, nrOfSeries, nrOfInstances;
        int st, se, in;
                
        boolean updateStudyOnly, updateSeriesOnly, instanceExists;
        boolean instancesInserted = false;
                
        DefaultTreeModel treemodel = (DefaultTreeModel) tree.getModel();
        tree.collapseRow (0);
        
        if (reloadAll) root.removeAllChildren();
        TreeElement test, tese, tein;
        
        DefaultMutableTreeNode currStudyNode, someStudyNode;
    	DefaultMutableTreeNode currSeriesNode, someSeriesNode;
	    DefaultMutableTreeNode currInstanceNode;
        
        currStudyNode = someStudyNode = new DefaultMutableTreeNode ();
        currSeriesNode = someSeriesNode = new DefaultMutableTreeNode ();
        
        
        nrOfStudies = dvi.getNumberOfStudies ();
        
        boolean isPSSeries = false;
        boolean isPSInstance = false;
        boolean isNew = false;
        
        String dotline = new String("Loading ");
             
        for (st = 0; st < nrOfStudies; st++)
        {   
            int status = dvi.selectStudy (st);
            if (status != jE_Condition.EC_Normal)continue;
            if (reloadAll)
            {
                int percent = (((st+1) * 100) / nrOfStudies);
		        Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,(dotline + percent + "%")));
            }
            
            
            instancesInserted = false;
            
            
            
            int stStatus = dvi.getStudyStatus();
            if (!reloadAll && !(stStatus == jDVIFhierarchyStatus.DVIF_objectIsNew ||
                stStatus == jDVIFhierarchyStatus.DVIF_objectContainsNewSubobjects)) continue;
            
            test = new TreeElement ("Study", st);
            test.UID = dvi.getStudyUID();
            test.Description = dvi.getStudyDescription();
                        
            test.DateTime = toReadableDate(dvi.getStudyDate());
            if (test.DateTime == null) test.DateTime = toReadableTime(dvi.getStudyTime());
            else if (toReadableTime(dvi.getStudyTime()) != null) test.DateTime = test.DateTime + ", " + toReadableTime(dvi.getStudyTime());
            
            test.PatientInfo = dvi.getPatientName();
            if (toReadableDate(dvi.getPatientBirthDate()) != null) test.PatientInfo = test.PatientInfo + ", " + toReadableDate(dvi.getPatientBirthDate());
            
                       
            // ---
            currStudyNode = someStudyNode;
            updateStudyOnly = false;
            int cc = root.getChildCount ();
	        for (int i = 0; i < cc; i++)
	        {
	            DefaultMutableTreeNode child = (DefaultMutableTreeNode) root.getChildAt (i);
	            TreeElement teC = (TreeElement) child.getUserObject();
        	        
        	    if (teC.UID.equals (test.UID))
        	    {
        	        updateStudyOnly = true;
        	        currStudyNode = child;        	        
        	    }	                	        
	        }  	        
	        
	        if (!updateStudyOnly) currStudyNode = new DefaultMutableTreeNode ();            
            // ---
            
            nrOfSeries = dvi.getNumberOfSeries ();
            for (se = 0; se < nrOfSeries; se++)
            {
               int serStatus=  dvi.selectSeries (se);
                if (serStatus != jE_Condition.EC_Normal)continue;
                
               
                int seStatus = dvi.getSeriesStatus();
                if (!reloadAll && !(seStatus == jDVIFhierarchyStatus.DVIF_objectIsNew ||
                    seStatus == jDVIFhierarchyStatus.DVIF_objectContainsNewSubobjects)) continue;
                                       
                isPSSeries = dvi.isPresentationStateSeries();
                               
                tese = new TreeElement ("Series", st, se);
                tese.UID = dvi.getSeriesUID();
                
                tese.DateTime = toReadableDate(dvi.getSeriesDate());
                if (tese.DateTime == null) tese.DateTime = toReadableTime(dvi.getSeriesTime());
                else if (toReadableTime(dvi.getSeriesTime()) != null) tese.DateTime = tese.DateTime + ", " + toReadableTime(dvi.getSeriesTime());
                
                tese.Description = dvi.getSeriesDescription();
                
                // ---
                currSeriesNode = someSeriesNode;
                updateSeriesOnly = false;
                cc = currStudyNode.getChildCount ();         
                
	            for (int i = 0; i < cc; i++)
	            {
	                DefaultMutableTreeNode child = (DefaultMutableTreeNode) currStudyNode.getChildAt (i);
	                TreeElement teC = (TreeElement) child.getUserObject();
            	        
        	        if ((teC.UID).equals (tese.UID))
        	        {
        	            updateSeriesOnly = true;
        	            currSeriesNode = child;
        	        }    	                	        
	            }      	        
	            
	            if (!updateSeriesOnly) currSeriesNode = new DefaultMutableTreeNode ();
                
                // ---
                nrOfInstances = dvi.getNumberOfInstances ();
                for (in = 0; in < nrOfInstances; in++)
                {                 
                    int intStatus = dvi.selectInstance (in);
                    if (intStatus != jE_Condition.EC_Normal)continue;
                    
                    isNew = dvi.getInstanceStatus() == jDVIFhierarchyStatus.DVIF_objectIsNew ? true : false;
                    if (!reloadAll && !isNew) continue;
                    
                    
                    tese.Modality = dvi.getModality();
                    
                    isPSInstance = dvi.isPresentationState();                    
                                        
                    if (isPSInstance)
                    {
                        currInstanceNode = new DefaultMutableTreeNode (tein = new TreeElement ("PS", st, se, in));
                        tein.setToPS();
                        tein.Modality = dvi.getModality();
                    }
                    else
                    {
                        currInstanceNode = new DefaultMutableTreeNode (tein = new TreeElement ("Image", st, se, in));
                        tein.Modality = dvi.getModality();
                    }
                    tein.UID = dvi.getInstanceUID();
                    
                    tein.Filename = dvi.getFilename(test.UID, tese.UID, tein.UID);
                    tein.Description = dvi.getPresentationDescription();
                    tein.Label = dvi.getPresentationLabel();
                    
                    // ---
                    instanceExists = false;
                    cc = currSeriesNode.getChildCount ();
                   
                   	for (int i = 0; i < cc; i++)
	                {
	                    DefaultMutableTreeNode child = (DefaultMutableTreeNode) currSeriesNode.getChildAt (i);
	                    TreeElement teC = (TreeElement) child.getUserObject();
                	        
        	            if (teC.UID.equals (tein.UID))
        	            {
        	                instanceExists = true;
        	            }        	                	        
	                }
	                // ---
	                
	                if (isNew)
                    {
                        tein.setToNew();
                        tese.setToNew();
                        test.setToNew();
                    }
                    else
                    {
                        tein.setToOld();
                        tese.setToOld();
                        test.setToOld();
                    }

                    if (!instanceExists)
	                {    
                        currSeriesNode.add (currInstanceNode);
                        instancesInserted = true;
                    }
                }

                if (instancesInserted) currSeriesNode.setUserObject (tese);
                if (!updateSeriesOnly) currStudyNode.add (currSeriesNode);
                else if (instancesInserted) treemodel.nodeChanged (currSeriesNode);  
            }
            
            if (instancesInserted)currStudyNode.setUserObject(test);
            if (!updateStudyOnly) treemodel.insertNodeInto(currStudyNode, root, root.getChildCount());            
            else if (instancesInserted) treemodel.nodeChanged (currStudyNode);  
            
            
            if (instancesInserted) treemodel.reload(currSeriesNode);
            if (instancesInserted) treemodel.reload(currStudyNode);
            
                            
            if (reloadAll && st == 0) // Expand and redraw
            {
                tree.expandRow (0);
                TreeChanged();                    
            }
        }
       
        dvi.releaseDatabase();
        
        tree.expandRow (0);
        
        if (reloadAll)
        {
       
            TreeChanged ();            
        }        
        
        suspendThread = false;
        DBlocked = false;
   	}


    /** Handler class for button events */
	class SymAction implements java.awt.event.ActionListener
	{
	    /**
	     * the event method
	     * 
	     * @param event the action event
	     */
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();
	    	if (object == loadBt)
	    	{
	    	    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Loading Instance"));
	    	    OnLoad ();	    	    
	    	}
	    	else if (object == loadfileBt)
	    	{
	    	    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Loading from File"));
	    	    OnLoadFile();
	    	}
	    	
	    	else if (object == sendBt) 
			{
			    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Send to Network"));
			    OnSend ();
			}
			
			else if (object == exitBt) 
			{
			    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Exit."));
			    parentF.DICOMscope_WindowClosing(null);
			}
			else if (object == refreshBt)
	    	{
	    	    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Refreshing Browser"));
	    	    root.removeAllChildren();
	    	    DefaultTreeModel treemodel= (DefaultTreeModel) tree.getModel();
	            treemodel.reload();
	    	    LoadAll(true);
	    	}
			else if (object == deleteBt) 
			{
			   Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Delete IOD(s)"));
			    OnDelete ();
			}
			else if (object == uidCb || object == patiCb || object == modaCb ||
			    object == descCb || object == newiCb || object == timeCb ||
			    object == fileCb || object == lablCb) TreeChanged ();
			
		}
	}
	
	/**
	 * called if the load-file button was clicked. A File-Open-Dialog wil appear and
	 * ask for a filename from the dicom file. Then another FileOpen Dialogbox will 
	 * appear to ask for a presentation state file. You may click on Cancel to load no
	 * presentation state. After a successful load the viewer is shown with the loaded
	 * image.
	 * 
	 * @since 30.03
	 */
	public void OnLoadFile ()
	{	
	    suspendThread = true;
	    
	    //Load Dicom File
	    JFileChooser openDlg = new JFileChooser ();
	    openDlg.setDialogTitle( "Open DICOM File");
	    
	    //Opens the Dialog 
	    if (oldLoadFileDir != null) openDlg.setCurrentDirectory (oldLoadFileDir);
	    openDlg.showOpenDialog(null);
	    oldLoadFileDir = openDlg.getCurrentDirectory();
	    
	    if (openDlg.getSelectedFile() == null)
	    {
	        suspendThread = false;
	        return;
	    }
	    String filename = openDlg.getSelectedFile().getPath();
	    fileN = filename;
	    System.out.println("Status: ");
	    int status = dvi.loadImage (filename);
	    System.out.println("status: "+status);
	  	  
	    if (status != 0) // Fehler
	    {	        
	        Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Load Failed."));
	        (Toolkit.getDefaultToolkit()).beep();
	        return;
	    }
	    
	    Controller.instance().fireEvent(new ImageActionEvent(this,ImageActionEvent.ACTION_SETNEWIMAGE));
	    parentF.switchToViewer();
        
        setCursor (new Cursor (Cursor.DEFAULT_CURSOR));
        
        suspendThread = false;        
	}

	/**
	 * called if the load-file button was clicked. A File-Open-Dialog wil appear and
	 * ask for a filename from the dicom file. Then another FileOpen Dialogbox will 
	 * appear to ask for a presentation state file. You may click on Cancel to load no
	 * presentation state. After a successful load the viewer is shown with the loaded
	 * image.
	 * 
	 * @since 30.03
	 */
	public void OnLoadPSFile ()
	{	
	    suspendThread = true;
	    setCursor (new Cursor (Cursor.WAIT_CURSOR));
	    
	    //Load Dicom File
	    JFileChooser openDlg = new JFileChooser ();
	    if (oldLoadFileDir != null) openDlg.setCurrentDirectory (oldLoadFileDir);
	    openDlg.setDialogTitle ("Open Presentation State");
	    openDlg.showOpenDialog(null);
	    oldLoadFileDir = openDlg.getCurrentDirectory();
	    String presstate = null;
	    
	    if (openDlg.getSelectedFile() == null)
	    {
	        suspendThread = false;
                setCursor (new Cursor (Cursor.DEFAULT_CURSOR));
	        return;
	    }
	    presstate = openDlg.getSelectedFile().getPath();
	    int    status = dvi.loadPState (presstate, fileN);
	  	  
	    if (status != 0) // Fehler
	    {	        
	        Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Load Failed."));
	        (Toolkit.getDefaultToolkit()).beep();
                setCursor (new Cursor (Cursor.DEFAULT_CURSOR));
	        return;
	    }
	    
	    Controller.instance().fireEvent(new ImageActionEvent(this,ImageActionEvent.ACTION_SETNEWIMAGE));
	    parentF.switchToViewer();
        
        setCursor (new Cursor (Cursor.DEFAULT_CURSOR));
        
        suspendThread = false;        
	}
	
	
	/**
	 * called after the load button was clicked. This method loads the selected instance
	 * or presentation state. If an instance was selected that have at least one 
	 * presentation state, a dialog box will appear. In this box you may select a 
	 * presentation state or the default state. Then the viewer will be shown with
	 * the loaded instance / presentation state.
	 * 
	 * @since 30.03
	 */
	public void OnLoad()
	{
	    if (DBlocked) // wait (if images are right now loaded)
	    {
	        try
	        {
	            while (DBlocked) Thread.sleep (250);	            
	        }
	        catch (Exception e)
	        {
	        }
	    }
	    	    
	    TreeElement te = null;
	    
	    te = getSelectedTreeElement ();
	    
	        
	    if (te == null) 
	    {
		        Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Can't Load - No Selection!"));
	        return;
	    }
	    
	    if (te.studyIdx == -1) 
	    {	        
	        // LoadAll(false); // Load only new
	                
	        return;
	    }	    
	    	    
	    if (te.instanceIdx == -1 && !te.isPS())
	    {
	        Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Only Images and Presentation States can be loaded!"));
	        return ;
	    }
	    
	    suspendThread = true;
	    
	    String instanceUID, seriesUID, studyUID;
	    
	    TreePath tp = tree.getLeadSelectionPath();        	        
	    DefaultMutableTreeNode dm = (DefaultMutableTreeNode) tp.getLastPathComponent();	    
	    
	    instanceUID = te.UID;
	        
	    DefaultMutableTreeNode dmse = (DefaultMutableTreeNode) dm.getParent();
	    TreeElement tese = (TreeElement) dmse.getUserObject();
	    seriesUID = tese.UID;
	        
	    DefaultMutableTreeNode dmst = (DefaultMutableTreeNode) dmse.getParent();
	    TreeElement test = (TreeElement) dmst.getUserObject();
	    studyUID = test.UID;
	    	    
	    DBlocked = true;
	    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Loading Image / Presentation State"));	    
	    
	    int status;	    
	    
	    setCursor (new Cursor (Cursor.WAIT_CURSOR));
    
	    if (!te.isPresentationState) 
	    {	
	        status = selectPState(te, instanceUID, seriesUID, studyUID);
	    
	        if (status == -1) 
	        {
	            DBlocked = false;	
	            suspendThread = false;
	            setCursor (new Cursor (Cursor.DEFAULT_CURSOR));
	            System.out.println("Return");
	            return;
	        }
	    }
	    else 
	    {
	        status = dvi.loadPState(studyUID, seriesUID, instanceUID);
	    }
	    
	    if (status != 0) // Fehler
	    {
	        DBlocked = false;
	        suspendThread = false;
	        Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Load Failed."));
                setCursor (new Cursor (Cursor.DEFAULT_CURSOR));
	        (Toolkit.getDefaultToolkit()).beep();
	        return;
	    }

	    status = dvi.instanceReviewed(studyUID, seriesUID, instanceUID);	    
        status = dvi.releaseDatabase();


        
	    Controller.instance().fireEvent(new ImageActionEvent(this,ImageActionEvent.ACTION_SETNEWIMAGE));
	    parentF.switchToViewer();
	    DBlocked = false;
	    
	    setCursor (new Cursor (Cursor.DEFAULT_CURSOR));
	    
	    te.setToOld();    
	    
	    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Ready."));
	    
	    suspendThread = false;
	    
	   
	    // refresh browser
	    root.removeAllChildren();
	    DefaultTreeModel treemodel = (DefaultTreeModel) tree.getModel();
	    treemodel.reload();
	    LoadAll(true);
	   
	    // expand Tree at loaded element
	    int cc = root.getChildCount ();
	    
	    for (int i = 0; i < cc; i++)
	    {
	        DefaultMutableTreeNode studynode = (DefaultMutableTreeNode) root.getChildAt (i);
	        te = (TreeElement) studynode.getUserObject();
	        
	        if (studyUID.equals (te.UID))
	        {   
	            int c = studynode.getChildCount ();
	            for (int j = 0; j < c; j++)
	            {
	                DefaultMutableTreeNode seriesnode = (DefaultMutableTreeNode) studynode.getChildAt (j);
	                te = (TreeElement) seriesnode.getUserObject();
        	        if (seriesUID.equals (te.UID))
	                {  
	                    tree.expandPath (new TreePath (seriesnode.getPath()));
        	            
	                    treemodel.nodeChanged(studynode);
	                    treemodel.nodeChanged(seriesnode);
	                }	        
	            }
	        }
	    }
	}
	/**
	 * called after the load button was clicked. This method loads the selected instance
	 * or presentation state. If an instance was selected that have at least one 
	 * presentation state, a dialog box will appear. In this box you may select a 
	 * presentation state or the default state. Then the viewer will be shown with
	 * the loaded instance / presentation state.
	 * 
	 * @since 30.03
	 */
	public void OnPrintHC()
	{
	    if (DBlocked) // wait (if images are right now loaded)
	    {
	        try
	        {
	            while (DBlocked) Thread.sleep (250);	            
	        }
	        catch (Exception e)
	        {
	        }
	    }
	    	    
	    TreeElement te = null;
	    
	    te = getSelectedTreeElement ();
	    
	        
	    if (te == null) 
	    {
		        Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Can't Add to Print - No Selection!"));
	        return;
	    }
	    
	    if (te.studyIdx == -1) 
	    {	        
	        // LoadAll(false); // Load only new
	                
	        return;
	    }	    
	    if (te.instanceIdx == -1 || !te.Modality.equals("HC"))
	    {
	        
	        Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Error: Add only Hardcopy Images to Print Job"));
	        return ;
	    }
	    suspendThread = true;
	    
	    String instanceUID, seriesUID, studyUID;
	    
	    TreePath tp = tree.getLeadSelectionPath();        	        
	    DefaultMutableTreeNode dm = (DefaultMutableTreeNode) tp.getLastPathComponent();	    
	    
	    instanceUID = te.UID;
	        
	    DefaultMutableTreeNode dmse = (DefaultMutableTreeNode) dm.getParent();
	    TreeElement tese = (TreeElement) dmse.getUserObject();
	    seriesUID = tese.UID;
	        
	    DefaultMutableTreeNode dmst = (DefaultMutableTreeNode) dmse.getParent();
	    TreeElement test = (TreeElement) dmst.getUserObject();
	    studyUID = test.UID;
	    	    
	    DBlocked = true;
	    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Add Hardcopy Image to Print"));	    
	    
	    int status;	    
	    
	    setCursor (new Cursor (Cursor.WAIT_CURSOR));
        /*
	    if (!te.isPresentationState) 
	    {	
	        status = selectPState(te, instanceUID, seriesUID, studyUID);
	        if (status == -1) 
	        {
	            DBlocked = false;	
	            suspendThread = false;
	            return;
	        }
	    }
	    else 
	    {
	        status = dvi.loadPState(studyUID, seriesUID, instanceUID);
	    }
	    */
	    status = dvi.addToPrintHardcopyFromDB(studyUID, seriesUID, instanceUID);
	    if (status != 0) // Fehler
	    {
	        DBlocked = false;
	        suspendThread = false;
	        Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Load Failed."));
	        (Toolkit.getDefaultToolkit()).beep();
                setCursor (new Cursor (Cursor.DEFAULT_CURSOR));
	        return;
	    }

	    status = dvi.instanceReviewed(studyUID, seriesUID, instanceUID);	    
        status = dvi.releaseDatabase();


        
	    Controller.instance().firePrint(new PrintEvent(this));
	    DBlocked = false;
	    
	    setCursor (new Cursor (Cursor.DEFAULT_CURSOR));
	    
	    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Ready"));
	    
	    suspendThread = false;
	    
	   
	   
	}
	
	/**
	 * called after the SendTo button was clicked. A list box will appear to select the
	 * destination workstation to send the selected study/series/instance/presentation
	 * state to. Details can be requested with the Detail button.
	 * 
	 * @since 30.03
	 */
	public void OnSend()
	{   	    
	    TreeElement te = getSelectedTreeElement ();	    
	    if (te == null) return;
	    
	    TreePath tp = tree.getLeadSelectionPath();
	    DefaultTreeModel treemodel= (DefaultTreeModel) tree.getModel();
	    
	    if (tp == null) return ;
	        
	    DefaultMutableTreeNode dm = (DefaultMutableTreeNode) tp.getLastPathComponent();	    
	    MutableTreeNode parent = (MutableTreeNode) dm.getParent();
	    if (parent == null) return; // root element ? -> abort
	    	    
	    
	    String instanceUID, seriesUID, studyUID;
	    
	    if (te.instanceIdx != -1)
	    {
	        instanceUID = te.UID;
	        
	        DefaultMutableTreeNode dmse = (DefaultMutableTreeNode) dm.getParent();
	        TreeElement tese = (TreeElement) dmse.getUserObject();
	        seriesUID = tese.UID;
	        
	        DefaultMutableTreeNode dmst = (DefaultMutableTreeNode) dmse.getParent();
	        TreeElement test = (TreeElement) dmst.getUserObject();
	        studyUID = test.UID;
	    }
	    else
	    if (te.seriesIdx != -1)
	    {
	        instanceUID = null;
	        seriesUID = te.UID;
	        
	        DefaultMutableTreeNode dmst = (DefaultMutableTreeNode) dm.getParent();
	        TreeElement test = (TreeElement) dmst.getUserObject();
	        studyUID = test.UID;	        
	    }
	    else
	    {
	        instanceUID = null;
	        seriesUID = null;
	        studyUID = te.UID;
	    }    
	    	    
        // Dialog
	    SendToDlg sdlg = new SendToDlg (parentF, dvi);
	    sdlg.show();
	    
	    if (!sdlg.okClicked) return;    
	   
        Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Network - Sending IOD"));
                
	    if (instanceUID != null) dvi.sendIOD (sdlg.selectedItem, studyUID, seriesUID, instanceUID);
	    else if (seriesUID != null) dvi.sendSeries (sdlg.selectedItem, studyUID, seriesUID);
	    else if (studyUID != null) dvi.sendStudy (sdlg.selectedItem, studyUID);	    
	}
	/**
	 * called after the Dump button was clicked. A list box will appear to select the
	 * destination workstation to send the selected study/series/instance/presentation
	 * state to. Details can be requested with the Detail button.
	 * 
	 * @since 30.03
	 */
	public void OnDump()
	{   	    
	    TreeElement te = getSelectedTreeElement ();	    
	    if (te == null) return;
	    
	    TreePath tp = tree.getLeadSelectionPath();
	    DefaultTreeModel treemodel= (DefaultTreeModel) tree.getModel();
	    
	    if (tp == null) return ;
	        
	    DefaultMutableTreeNode dm = (DefaultMutableTreeNode) tp.getLastPathComponent();	    
	    MutableTreeNode parent = (MutableTreeNode) dm.getParent();
	    if (parent == null) return; // root element ? -> abort
	    	    
	    
	    String instanceUID, seriesUID, studyUID;
	    
	    if (te.instanceIdx != -1)
	    {
	        instanceUID = te.UID;
	        
	        DefaultMutableTreeNode dmse = (DefaultMutableTreeNode) dm.getParent();
	        TreeElement tese = (TreeElement) dmse.getUserObject();
	        seriesUID = tese.UID;
	        
	        DefaultMutableTreeNode dmst = (DefaultMutableTreeNode) dmse.getParent();
	        TreeElement test = (TreeElement) dmst.getUserObject();
	        studyUID = test.UID;
	    }
	    else
	    if (te.seriesIdx != -1)
	    {
	        instanceUID = null;
	        seriesUID = te.UID;
	        
	        DefaultMutableTreeNode dmst = (DefaultMutableTreeNode) dm.getParent();
	        TreeElement test = (TreeElement) dmst.getUserObject();
	        studyUID = test.UID;	        
	    }
	    else
	    {
	        instanceUID = null;
	        seriesUID = null;
	        studyUID = te.UID;
	    }    
	    	 
        System.out.println(   studyUID);    
        System.out.println(   seriesUID);    
        System.out.println(   instanceUID);    
	if (instanceUID != null) dvi.dumpIOD(studyUID, seriesUID, instanceUID);
	}
	
	/**
	 * called after the delete button was clicked. Deletes all studies, one study/series
	 * or instance/presentation state.
	 * 
	 * @since 30.03
	 */
	public void OnDelete()
	{	
	    if (DBlocked) return;	    
	    
	    DBlocked = true;
	    TreeElement te = getSelectedTreeElement ();
	    if (te == null) 
	    {
	        DBlocked = false;
	        return;
	    }
	    
	    ConfirmationDlg cdlg = new ConfirmationDlg (parentF);
	    cdlg.show();
	    
	    if (!cdlg.okClicked) 
	    {
	        DBlocked = false;
	        return;
	    }
	    
	    TreePath tp = tree.getLeadSelectionPath();
	    DefaultTreeModel treemodel= (DefaultTreeModel) tree.getModel();
	    
	    if (tp == null) 
	    {
	        DBlocked = false;
	        return ;
	    }
	        
	    DefaultMutableTreeNode dm = (DefaultMutableTreeNode) tp.getLastPathComponent();	    
	    MutableTreeNode parent = (MutableTreeNode) dm.getParent();
	    
	    if (parent == null) // root element? 
	    {
	        ConfirmationDlg cdlg2 = new ConfirmationDlg (parentF);
	        cdlg2.setLabelText("Delete all Studies?");
	        cdlg2.show();
	        if (!cdlg2.okClicked) 
	        {
	            DBlocked = false;
	            return;	        
	        }
	        
	        root.removeAllChildren();
	        treemodel.reload();
	        
	        // delete all from the database...
	        
	        String studyUID;
	        while (dvi.getNumberOfStudies() > 0)
	        {
	            dvi.selectStudy(0);
	            studyUID = dvi.getStudyUID();
	            dvi.deleteStudy(studyUID);
	        }	        
	    }
	    else 
	    {
	        String instanceUID, seriesUID, studyUID;
	    
	        if (te.instanceIdx != -1)
	        {
	            instanceUID = te.UID;
    	        
	            DefaultMutableTreeNode dmse = (DefaultMutableTreeNode) dm.getParent();
	            TreeElement tese = (TreeElement) dmse.getUserObject();
	            seriesUID = tese.UID;
    	        
	            DefaultMutableTreeNode dmst = (DefaultMutableTreeNode) dmse.getParent();
	            TreeElement test = (TreeElement) dmst.getUserObject();
	            studyUID = test.UID;
	            
	            dvi.deleteInstance(studyUID, seriesUID, instanceUID);
	            
	            treemodel.removeNodeFromParent(dm);
	            if (dmse.getChildCount() == 0) treemodel.removeNodeFromParent(dmse);
	            if (dmst.getChildCount() == 0) treemodel.removeNodeFromParent(dmst);
	        }
	        else
	        if (te.seriesIdx != -1)
	        {	            
	            seriesUID = te.UID;
    	        
	            DefaultMutableTreeNode dmst = (DefaultMutableTreeNode) dm.getParent();
	            TreeElement test = (TreeElement) dmst.getUserObject();
	            studyUID = test.UID;	        
	    
	            dvi.deleteSeries(studyUID, seriesUID);
	            
	            treemodel.removeNodeFromParent(dm);	            
	            if (dmst.getChildCount() == 0) treemodel.removeNodeFromParent(dmst);
	        }
	        else
	        {	            
	            studyUID = te.UID;
	            
	            dvi.deleteStudy(studyUID);
	            
	            treemodel.removeNodeFromParent(dm);	            
	        }
	    }
	    
	    dvi.releaseDatabase();
	    DBlocked = false;	    
	    
	    // refresh browser
	    root.removeAllChildren();	    
	    treemodel.reload();
	    LoadAll(true);
	    
	}
    
    /**
     * Gets the selected tree element
     * 
     * @return the tree element
     * @since 30.03
     */
    protected TreeElement getSelectedTreeElement ()
    {
        TreePath tp = tree.getLeadSelectionPath();
        if (tp == null) return null;
	        
	    DefaultMutableTreeNode dm = (DefaultMutableTreeNode) tp.getLastPathComponent();
	    return (TreeElement) dm.getUserObject();
    }
    
    /**
     * Corrects the given date (yyyymmdd) to a "readable" date (mm/dd/yyyy).
     * if the year is 2 digits long, the output will be "mm/dd/yy".
     * 
     * @param ddate  a date to correct
     * @return the corrected date
     * @since 30.03
     */
	protected String toReadableDate (String ddate)
	{
        if (ddate.length () == 8) // long format
        {
            return ddate.substring (4, 6) + "/" + ddate.substring (6, 8) + "/" + ddate.substring (0, 4);
        }
        else if (ddate.length () == 6) // short format
        {
            return ddate.substring (2, 4) + "/" + ddate.substring (4, 6) + "/" + ddate.substring (0, 2);
        }
        else return null;
	}	
	
	/**
	 * Corrects the given time (hhmmss) to a "readable" time (hh:mm).
	 * 
	 * @param dtime   a time to correct.
	 * @return the corrected time
	 * @since 30.03
	 */
	protected String toReadableTime (String dtime)
	{
        if (dtime.length () == 6) // short format
        {
            return dtime.substring (0, 2) + ":" + dtime.substring (2, 4);
        }
        else return null;
	}		
	
	
	/**
	 * Starts the Thread
	 * 
	 * @since 30.03
	 */
	public void startThread()
	{
	    ut = new UpdateThread (this, dvi);
	    
	    ut.start();
	    System.out.println("Started updateThread");
	}
	
	
	/**
	 * Selects a PState for a loaded image.
	 * 
	 * @param te          the selected Tree element
	 * @param instanceUID the instance UID
	 * @param seriesUID   series UID
	 * @param studyUID    study UID
	 * @since 30.03
	 */
	public int selectPState(TreeElement te, String instanceUID, String seriesUID, String studyUID)
	{
	    int status;
	    
	    JDialog selPStatDlg = new JDialog (parentF, "Select Presentation State", true);
	    
	    DefaultListModel lm = new DefaultListModel(); 
	    JList info = new JList(lm);	    
	    	    
	    selPStatDlg.getContentPane().setLayout (new BorderLayout (5, 5));
	    selPStatDlg.setLocation (200, 150);
	    
	    DisposeCommand okDC, cancelDC;
	    
	    CommandJButton okBt = new CommandJButton (okDC = new DisposeCommand(selPStatDlg), 0);
	    okBt.setText("  Ok  ");
		okBt.setBackground(java.awt.Color.lightGray);		
		JPanel p = new JPanel ();
		p.add (okBt);
		
		CommandJButton cancelBt = new CommandJButton (cancelDC = new DisposeCommand(selPStatDlg), 1);
	    cancelBt.setText("  Cancel  ");
		cancelBt.setBackground(java.awt.Color.lightGray);				
		p.add (cancelBt);
		
		MainContext mc = MainContext.instance();
		
		dvi.selectStudy (te.studyIdx);
	    dvi.selectSeries (te.seriesIdx);
	    dvi.selectInstance (te.instanceIdx);
		
		lm.addElement ("<default>");
		int nps = dvi.getNumberOfPStates();		
		if (nps == 0) 
		{
		    return dvi.loadImage(studyUID, seriesUID, instanceUID);		    
		}
		
		for (int i = 0; i < nps; i++)
		{
		    String descr = dvi.getPStateDescription(i);
		    String label = dvi.getPStateLabel(i);
		    if (descr == null) descr = new String ("<no descr>");
		    else if (descr.length() == 0) descr = new String ("<no descr>");
		    if (label == null) label = new String ("<no label>");
		    else if (label.length() == 0) label = new String ("<no label>");
		    
		    lm.addElement (label + " * " + descr);
		}
		
		info.setSelectedIndex(0);
		
		selPStatDlg.getContentPane().add ("South", p);
		selPStatDlg.getContentPane().add ("Center", new JScrollPane(info));
		
	    selPStatDlg.pack();
	    selPStatDlg.setVisible(true);
	    
	   if (cancelDC.wasClicked()) 
	   {
	     return -1;
	    }
	    	    
	    int sidx = info.getSelectedIndex() - 1;
	    
	    status = dvi.loadImage(studyUID, seriesUID, instanceUID);
	    
	    if (sidx >= 0) 
	    {	
	        status = dvi.selectPState (sidx, true);
	       
	        if (status != jE_Condition.EC_Normal) Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"PS Load Failed"));
	    }	    	    
	    return status;
	}   
	    	
			
	public boolean processEvent (DSEvent e)
	{
	    if (e instanceof DbActionEvent)
	    {
            DbActionEvent de = (DbActionEvent)e;
            switch (de.type)
            {
                case de.LOAD_IM: 
	    	                    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Loading Image from File"));
                                OnLoadFile();
                                break;
                case de.LOAD_PS:
	    	                    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Loading Presentation State from File"));
                                OnLoadPSFile();
                                break;
                case de.LOAD_DB:
	    	                    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Loading Image"));
                                OnLoad();
                                
                                break;
                case de.SAVE_DB:
                                onSave();
                                break;
                case de.SAVE_AS:
                                OnSaveFile();
                                break;
                case de.SAVE_SCREEN:
                                Controller.instance().fireEvent(new RequestEvent(this,RequestEvent.REQUEST_SCREEN));
                                break;
                case de.REFRESH:
	    	                    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Refreshing Browser"));
	    	                    root.removeAllChildren();
	    	                    DefaultTreeModel treemodel= (DefaultTreeModel) tree.getModel();
	                            treemodel.reload();
                                LoadAll(true);
                                break;
                                
                case de.DELETE:
			                    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Delete IOD(s)"));
                                OnDelete();
                                break;
                case de.SENDTO:
			                    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Send IOD to Network"));
                                OnSend();
                                break;
                case de.PRINTHC:
	    	                    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Add Hardcopy Image to Print"));
                                OnPrintHC();
                                break;
                case de.DUMP:
	    	                    Controller.instance().fireStatus(new StatusLineEvent(this,StatusLineEvent.SET_DES,DSComponentType.BROWSER,"Create Dump"));
                                OnDump();
                                break;
                                
                                
            }
	    }
	    if (e instanceof SendScreenEvent)
	    {
	        OnSaveScreen((SendScreenEvent) e);
	    }
	    
	    if (e instanceof ChangeOptionsEvent)
	    {
            setConfiguaration (((ChangeOptionsEvent)e).getConfig(), false);
	    }
	    
	    return false;
	}
	public void setConfiguaration(Hashtable config, boolean init)
	{
            if (config.containsKey("UID"))uidCb.setSelected(((Boolean)config.get("UID")).booleanValue());
            if (config.containsKey("Description"))descCb.setSelected(((Boolean)config.get("Description")).booleanValue());
            if (config.containsKey("PatientInfo"))patiCb.setSelected(((Boolean)config.get("PatientInfo")).booleanValue());
            if (config.containsKey("Modality"))modaCb.setSelected(((Boolean)config.get("Modality")).booleanValue());
            if (config.containsKey("DateTime"))timeCb.setSelected(((Boolean)config.get("DateTime")).booleanValue());
            if (config.containsKey("NewItems"))newiCb.setSelected(((Boolean)config.get("NewItems")).booleanValue());
            if (config.containsKey("Filename"))fileCb.setSelected(((Boolean)config.get("Filename")).booleanValue());
            if (config.containsKey("Label"))lablCb.setSelected(((Boolean)config.get("Label")).booleanValue());
	        TreeChanged ();
            if (config.containsKey("BrowserBackgroundColor"))
            {
                Color color = (Color)config.get("BrowserBackgroundColor");
                if (color != getBackground()) 
                {
                    tree.setBackground(color);
                    updateUI();
                }
            }
            
            if (config.containsKey("ButtonOn"))
            {
               if(((Boolean)config.get("ButtonOn")).booleanValue())
               {
                    if (!buttonsOn) 
                    {
                        add ("South", buttonPanel);
                        buttonsOn = true;
                        updateUI();
                    }
                    
               }
               else if (buttonsOn&&!init) 
               {
                    remove(buttonPanel);
                    buttonsOn = false;
                    updateUI();
               }
            }
            if (init)
            {
            if (config.containsKey("AutoUpdateStudyBrowser"))
            {
                boolean on  = ((Boolean)config.get("AutoUpdateStudyBrowser")).booleanValue();
                if (on) 
                {
                    startThread();
                }
            }
                
            }
	    
	}
	
	
    /**
     * Saves the current screen as a DICOM SC file.
     * You can save the files in different transfer syntax
     *
     * @since 30.03.1999
     */
    public void OnSaveScreen(SendScreenEvent e)
    {
	    JFileChooser saveDlg = new JFileChooser ();
	    saveDlg.setDialogTitle( "Save Current Screen as DICOM File");
	    
	    //Opens the Dialog 
	    if (oldLoadFileDir != null) saveDlg.setCurrentDirectory (oldLoadFileDir);
	    saveDlg.showSaveDialog(null);
	    oldLoadFileDir = saveDlg.getCurrentDirectory();
        
	    if (saveDlg.getSelectedFile() == null)return;
	    
	    String filename = saveDlg.getSelectedFile().getPath();
	    
	    boolean explicitVR = ChooseExplicitVR ();
	    
	        dvi.saveDICOMImage (filename, e.data, 
	            e.width, 
	            e.height, 
	            1.0, explicitVR, e.instanceUID);
    }
    public void onSave()
    {
        suspendThread = true;            
                
        //??Filling TLHC new 
        //int status = screenImageHandler.presentationStateGraphicsHandler.dvi.savePState("pres\\"+ presentationStatePanel.getNameLabel());
        dvi.savePState();
               
        //Updates the database 
        try 
        {
            Thread.sleep(2000);
        }
        catch(Exception ex)
        {}
        suspendThread = false;
        LoadAll (false);
    }
    /**
     * Creates and shows a Dialog where you can choose the transfer syntax
     * of the saving presentation state.
     *
     * @since 30.03.1999
     */
    public boolean ChooseExplicitVR ()
    {
        JRadioButton e, i;
	    JButton ok;
	    
	    JDialog expDlg = new JDialog (parentF, "Choose VR", true);
	    
	    expDlg.setLocation (200, 200);
	    expDlg.getContentPane().setLayout(new GridLayout(3, 1));
	    ButtonGroup group1 = new ButtonGroup();
	    e = new JRadioButton("Explicit VR Little Endian",  true);
	    i = new JRadioButton("Implicit VR Little Endian",  false);
	    group1.add(e);
	    group1.add(i);
        expDlg.getContentPane().add(e);
        expDlg.getContentPane().add(i);
        JPanel p = new JPanel ();
        p.add (ok = new CommandJButton ("OK", new DisposeCommand (expDlg), 0));        
        expDlg.getContentPane().add(p);
        expDlg.pack();
        expDlg.show();
        
        return e.isSelected();
    }
    
    /**
     * Saves the current presentation state and the dicom image as file.
     * You can save the files in different transfer syntax
     *
     * @since 30.03.1999
     */
    public void OnSaveFile()
    {
        
	    JFileChooser saveDlg = new JFileChooser ();
	    saveDlg.setDialogTitle( "Save DICOM File");
	    
	    //Opens the Dialog 
	    if (oldLoadFileDir != null) saveDlg.setCurrentDirectory (oldLoadFileDir);
	    saveDlg.showSaveDialog(null);
	    oldLoadFileDir = saveDlg.getCurrentDirectory();
        
	    if (saveDlg.getSelectedFile() == null)return;
	    
	    String filename = saveDlg.getSelectedFile().getPath();
	    
	    
	    
	    String DCMfilename =filename + ".dcm";
	    String PSfilename = filename + ".pres";

	    
	    	    
        boolean explicitVR = ChooseExplicitVR ();
	    dvi.savePState (PSfilename, explicitVR);
	    dvi.saveCurrentImage (DCMfilename, explicitVR);
    }

}
/*
 *  CVS Log
 *  $Log: StudyMan.java,v $
 *  Revision 1.2  2000/03/17 14:07:55  kleber
 *  chg: Layout texts on GUI
 *
 *  Revision 1.1.1.1  2000/03/13 14:39:52  kleber
 *  init log for first free release
 *
 *  Revision 1.2  1999/05/17 08:15:27  Schroeter
 *  Parameter documentation modified
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
