/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *
 *  Author :      $Author: kleber $
 *  Last update : $Date: 2000/03/13 14:39:52 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package dicomPrint;
import javax.swing.*;
import java.awt.*;
import javax.swing.border.*;
import J2Ci.*;

/**
 * This class contains the GUI for a page of a print job. 
 * This page can have the orientation portrait ( portrait = true)
 * or landscape (portrait = fasle) and will be drawn in a Panel. 
 * The page have a table of PrintImagePreview. Rows and cols of the table can be changed.
 * 
 * 
 * @author Klaus Kleber
 */
public class PreviewPanel extends JPanel
{

     /**
      * Contains the current jDVPSStoredPrint
      */
     jDVPSStoredPrint storedPrint;

    /**
     * Contains the x -coordiante for the page
     */
    int x;

    /**
     * Contains the y - coordinate for the page
     */
    int y;

    /**
     * Contains the height of the page
     */
    int h;

    /**
     * Contains the width of the page
     */
    int w;

    /**
     * w
     */
    JPanel page = new JPanel();

    /**
     * if true the page will be portrait, esle landscape
     */
    public boolean portrait = true;

    /**
     * Contains the minimum distance from the Panel 
     */
    public int border = 10;

    /**
     * Conatins the distance between the PrintImagePreview
     */
    int gaps = 5;

    /**
     * Contains the current number of cols
     */
    int cols = 1;

    /**
     * Contains the current number of rows
     */
    int rows = 1;

    /**
     * Contains the current MouseHandler.
     */
    PreviewMouseHandler previewMouseHandler;

    /**
     * Contains the current size for the PreviewPanel
     */
    Dimension size = new Dimension();

    /**
     * Contains Color for the background
     */
    Color backgroundColor = Color.white;
    
    
    /**
     * Contains Color for the page
     */
    Color pageColor = Color.lightGray;
    
    
    /**
    * true, if last page should be displayed, else the first page will be displayed;
    */
    boolean showLastPage = false;
    /**
     * Constructor.
     * 
     * @param previewMouseHandler Contains the current MouseHandler.
     * @param cols Contains the number of cols.
     * @param rows Contains the number of rows.
     * @param storedPrint Contains the current size for the PreviewPanel.
     */
    public PreviewPanel(PreviewMouseHandler previewMouseHandler, int cols, int rows,jDVPSStoredPrint storedPrint)
    {
        this.storedPrint = storedPrint;
        setLayout(null);
        setBackground(backgroundColor);
        
        this.previewMouseHandler= previewMouseHandler;
        this.cols = cols;
        this.rows = rows;
    }

    /**
     * Paints the component in the specified Graphics object
     * 
     * @param g w
     */
    public void paintComponent(Graphics g)
    {
        if (! size.equals(getSize()))
        {
            size =  getSize();
            calculateNewSize();
        }
        page.validate();
        super.paintComponent(g);
    }

    /**
     * Calculates the size of the page 
     */
    public void calculateNewSize()
    {
        //Removes all obejcts
        removeAll();
        page.removeAll();
        
        //Calculates the sizes for portrait
        if (portrait)
        {
            
            h = size.height-border;
            w = h*3/4;
            if (w > size.width-border)
            {
                double scaling = (double)w/(double)(size.width-border);
                
                h = (int)(h/scaling);
                w = size.width-border;
            }
        }
        //Calculates the size for landscape
        else
        {
            w = size.width-border;
            h = w*3/4;
            if (h > size.height-border)
            {
                double scaling = (double)h/(double)(size.height-border);
                w = (int)(w/scaling);
                h= size.height-border;
            }
            
        }   
        
        //Sets the size of the page
        page.setSize(new Dimension(w, h));
        
        //Sets the location of the page
        x = (size.width-w)/2;
        y = (size.height-h)/2;
        page.setLocation(x,y);
        
        page.setBackground(pageColor);
        page.setBorder(new EmptyBorder(gaps, gaps,gaps,gaps));
        page.setLayout(new GridLayout(rows,cols,gaps,gaps));
        
        int numberOfPlaces = rows*cols;
        int numberOfVisible = storedPrint.getNumberOfImages()%(numberOfPlaces);
        
        int pagesInJob = storedPrint.getNumberOfImages()/numberOfPlaces;
        if (storedPrint.getNumberOfImages()%numberOfPlaces>0)pagesInJob++;
        int offset = (pagesInJob-1)*cols*rows;
        
        
        for (int i = 0; i <numberOfPlaces; i++) 
        {
            
            PrintImagePreview im = new PrintImagePreview(offset+i);
            if ((i <numberOfVisible)|| ((numberOfVisible ==0)&& (storedPrint.getNumberOfImages()!= 0))) 
            {
                im.setReferToImage(true);
                im.setParameter(havePrintSettings(offset+i));
            }
            im.addMouseListener(previewMouseHandler);
            page.add(im);
        }
        
        add(page);
    }

    /**
     * Sets the orentation of the page. If portrait = true the page will be displayed in 
     * portrait else in landscape.
     * 
     * @param portrait If portrait = true the page will be displayed in 
     * portrait else in landscape.
     */
    public void setOrientation(boolean portrait)
    {
        if (this.portrait != portrait)
        {
            this.portrait = portrait;
            calculateNewSize();
            repaint();
            page.updateUI();
        }
    }

    /**
     * Set the cols of the page.
     * 
     * @param cols New cols
     */
    public void setCols(int cols)
    {
        if (this.cols != cols)
        {
            this.cols = cols;
            calculateNewSize();
            repaint();
            page.updateUI();
        }
    }
    /**
     * Set the rows of the page.
     * 
     * @param cols New cols
     */
    public void setRows(int rows)
    {
        if (this.rows != rows)
        {
            this.rows = rows;
            calculateNewSize();
            repaint();
            page.updateUI();
        }
    }

    /**
     * Sets rows and cols of the page
     * 
     * @param rows New rows
     * @param cols New cols
     */
    public void setRowsCols(int rows, int cols)
    {
            this.cols = cols;
            this.rows = rows;
            calculateNewSize();
            repaint();
            page.updateUI();
    }

    /**
     * Updates the Print Preview
     */
    public void updatePrintPreview()
    {
        calculateNewSize();
        repaint();
        page.updateUI();
        
        
    }

    /**
     * Sets a new jDVPSStoredPrint
     * 
     * @param storedPrint New jDVPSStoredPrint.
     */
    public void setStoredPrint(jDVPSStoredPrint storedPrint)
    {
        this.storedPrint = storedPrint;
    }
    /**
     * Check if the image with the specified index have his own print settings
     * 
     * @param index Index of the image
     * @return true if the image has his own print settings
     */
    public boolean havePrintSettings(int index)
    {
         if (index <= storedPrint.getNumberOfImages())
         {
             if ( (storedPrint.getImageConfigurationInformation(index) ==null)&&
            (storedPrint.getImageSmoothingType(index)== null)&&
            (storedPrint.getImageMagnificationType(index)== null)) return false;
            else return true;
         }
         return false;
        
    }
}
/*
 *  CVS Log
 *  $Log: PreviewPanel.java,v $
 *  Revision 1.1.1.1  2000/03/13 14:39:52  kleber
 *  init log for first free release
 *
*/
