/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *
 *  Author :      $Author: kleber $
 *  Last update : $Date: 2000/03/13 14:39:52 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package dicomPrint;

import java.awt.*;

import javax.swing.*;
import javax.swing.border.*;

/**
 * Objects of this class represent preview for one place on the current page 
 * in the current print job. PrintImagePreview have a border (with size = gaps)
 * and an inlinePanel.
 * refer to an image .
 * 
 * @author Klaus Kleber
 */
public class PrintImagePreview extends JPanel
{
    
    /**
     * Contains the size of the gaps on each side.
     */
    int gaps = 2;

    /**
     * Contains index of the image if exits. Every objects has this image. 
     */
    int index;

    /**
     * Contains the GUI of the PrintImagePreview without the border
     */
    JPanel inlinePanel;

    /**
     * if true the image have his own print settings
     */
    boolean haveParameter = false;

    /**
     * if true the PrintImagePreview refers to an image
     */
    boolean referToImage = false;

    /**
     * Contains the color for the border
     */
    private Color markedColor= Color.red;
    /**
     * Contains the color for drwaing on the PrintImagePreview
     */
    private Color drawColor = Color.white;
    
    /**
     * Contains the background color
     */
    private Color backgroundColor = Color.gray;
    
    /**
     * Contains the color for PrintImagePreviews  refering to an image.
     */
    private Color referColor = Color.black;
    /**
     * Constructor
     * 
     * @param index a
     */
    public PrintImagePreview(int index)
    {
        this.index = index;
        setLayout(new BorderLayout());
        inlinePanel = new JPanel();
        inlinePanel.setBackground(backgroundColor);
        setBorder(new EmptyBorder(gaps, gaps, gaps, gaps));
        add(inlinePanel, BorderLayout.CENTER);
    }

    /**
     * Paint the PrintImagePreview. If the PrintImagePreview refers to an image and the image
     * have his own print settings this will be marked (with an o).
     * 
     * @param g Contains the curren Graphics object
     */
    public void paint(Graphics g)
    {
        super.paint(g);
        if (haveParameter)
        {
            g.setColor(Color.white);
            g.drawString("opt.", getSize().width/2-2*gaps, getSize().height/2);
        }
    }

    /**
     * Marked/unmarked the image with an  border.
     * 
     * @param marked Sets/unset the  border
     */
    public void setMarked(boolean marked)
    {
        if (referToImage)
        {
            if (marked) setBackground(markedColor);
            else setBackground(backgroundColor);
        }
    }

    /**
     * Sets/unsets referToImage.
     * 
     * @param referToImage 
     */
    public void setReferToImage(boolean referToImage)
    {
        this.referToImage = referToImage;
        if (referToImage) inlinePanel.setBackground(referColor);
        else inlinePanel.setBackground(backgroundColor);
    } 

    /**
     * Gets the current index
     * 
     * @return The current index
     */
    public int getIndex()
    {
        return index;
    }

    /**
     * Return true if the PrintImagePreview refers to an image.
     * 
     * @return a
     */
    public boolean getReferToImage()
    {
        return referToImage;
    }

    /**
     * Set haveParameter. This value inicates that the image of the PrintImagePreview
     * has his own print settings.
     * 
     * @param haveParameter a
     */
    public void setParameter(boolean haveParameter)
    {
        
        this.haveParameter = haveParameter;
        repaint();
    }
}
/*
 *  CVS Log
 *  $Log: PrintImagePreview.java,v $
 *  Revision 1.1.1.1  2000/03/13 14:39:52  kleber
 *  init log for first free release
 *
*/
