/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *
 *  Author :      $Author: kleber $
 *  Last update : $Date: 2000/03/17 14:07:55 $
 *  Revision :    $Revision: 1.2 $
 *  State:        $State: Exp $
*/

package dicomPrint;

import java.awt.*;
import java.util.*;

import javax.swing.*;
import javax.swing.border.*;

import J2Ci.*;
import jToolkit.gui.*;
import main.*;

/**
 * This class contains the GUI and with the interactions 
 * for the Print - Panel of DICOMscope.
 * 
 * @author Klaus Kleber
 * @since 01.10.99
 */
public class PrintPanel extends JPanel implements CommandButtonListener, CommandTextListener, PrintListener, CommandToggleButtonListener
{


    /**
     * Contains the print Button
     */
    CommandJButton printButton;
    
    /**
     * Contains the remove-Button
     */
    CommandJButton removeButton;

    /**
     * Contains the ComboBox for changing the printer
     */
    CommandJComboBox printerCombo;

    /**
     * Contains the ComboBox for changing the medium
     */
    CommandJComboBox mediumCombo;;

    /**
     * Contains the ComboBox for changing the film size
     */
    CommandJComboBox filmSizeCombo;


    /**
     * Contains the ComboBox for changing the orientation
     */
    CommandJComboBox orientationCombo;
    
    /**
     * Contains the ComboBox for changing the priority
     */
    CommandJComboBox priorityCombo;
    
    /**
     * Contains the ComboBox for changing the priority
     */
    CommandJTextField copiesText;
    
    /**
     * Contains the ComboBox for changing the magnification type
     */
    CommandJComboBox magnificationCombo;

    /**
     * Contains the ComboBox for changing the smoothing type
     */
    CommandJComboBox smoothingCombo;

    /**
     * Contains the ComboBox for changing the configuration
     */
    CommandJComboBox configurationCombo;

    /**
     * Contains the ComboBox for changing the resolution
     */
    CommandJComboBox resolutionCombo;

    /**
     * Contains the ComboBox for changing the trim setting
     */
    CommandJComboBox trimCombo;

    /**
     * Contains the ComboBox for changing the cropping setting
     */
    CommandJComboBox croppingCombo;

    /**
     * Contains the ComboBox for changing the border setting
     */
    CommandJComboBox borderCombo;

    /**
     * Contains the ComboBox for changing the empty image setting
     */
    CommandJComboBox emptyImageCombo;
    
    /**
     * Contains the ComboBox for changing the min density setting
     */
    CommandJComboBox minDensityCombo;

    /**
     * Contains the ComboBox for changing the max density setting
     */
    CommandJComboBox maxDensityCombo;
    /**
     * Contains the TextField for illumination
     */
    CommandJTextField illuminationText;

    /**
     * Contains the TextField for reflection
     */
    CommandJTextField reflectionText;
    
    /**
     * Contains the TextField for annatation text
     */
    JTextField annotationText;

    /**
     * Contains the Checkbox for annatation date
     */
    JCheckBox annDateCheckBox;
    
    /**
     * Contains the Checkbox for annatation date
     */
    JCheckBox annPrinterNameCheckBox;
    
    /**
     * Contains the Checkbox for Illumination/Light date
     */
    JCheckBox annIllCheckBox;
    
    CommandJRadioButton annOnRadioButton;
    CommandJRadioButton annOffRadioButton;
    
    /**
     * Contains the ComboBox for rows/cols
     */
    CommandJComboBox layoutCombo;

    JPanel annPanel = new JPanel();
    boolean activeListener = false;
    
    //Ids for handling the action Events
    static final int ID_PRINTER = 0;
    static final int ID_MEDIUM = 1;
    static final int ID_FILMSIZE = 2;
    static final int ID_ORIENTATION = 3;
    static final int ID_LAYOUT = 200;
    static final int ID_MAGNIFICATION = 4;
    static final int ID_SMOOTHING = 5;
    static final int ID_CONFIGURATION = 6;
    static final int ID_RESOLUTION = 7;
    static final int ID_TRIM = 8;
    static final int ID_CROPPING = 9;
    static final int ID_BORDER = 10;
    static final int ID_EMPTYIMAGE = 11;
    static final int ID_MAXDENSITY = 12;
    static final int ID_MINDENSITY = 13;
    static final int ID_PRIORITY = 14;
    static final int ID_COPIES = 15;
    static final int ID_PRESENTATIONLUT = 50;
    static final int ID_ILLUMINATION = 51;
    static final int ID_REFLECTION = 52;
    static final int ID_PRINT = 100;
    static final int ID_REMOVE = 101;
    static final int ID_ANNON = 200;
    static final int ID_ANNOFF = 201;
    
   
    /**
     * Contains information about the number of images and pages in the current print job
     */
    JLabel imageLabel = new JLabel();
    
    
    /**
     * Contains the current rows settings.
     */
    long printerCurrentRows = 1;
    
    /**
     * Contains the current cols settings.
     */
    long printerCurrentCols = 1;
    
    /**
     * Contains the target printer of the print job
     */
    String target;
    
    /**
     * Contains current jDVPSStoredPrint object with informations about the print settings of the print job
     */
    jDVPSStoredPrint storedPrint;
    
    /**
     * Contains the DVInterface.
     */
    jDVInterface dvi ;

    /**
     * This object contains the GUI for the print preview
     */
    PreviewPanel previewPanel;
    
    
    /**
     * Contains the mouse handler for all objects of this PrintPanel
     */
    PreviewMouseHandler previewMouseHandler;
    
    /**
     * Contains the Color for the imageLabel
     */
    Color labelColor = Color.white;

    
    /**
     * If true cols and rows will be changed if orientation will be changed.
     */
    boolean currentOrientationIsPortrait = true;
    
    /**
     * Constructor. Build the GUI and initializes the widgets.
     * 
     * @param dvi Contains the dVIInterface.
     */
    public PrintPanel(jDVInterface dvi,Hashtable config )
    {
        this.dvi = dvi;
        setLayout(new BorderLayout());
        
        //init MouseHandler
        previewMouseHandler = new PreviewMouseHandler(this);
        
        Controller.instance().addPrintListener(this);
        storedPrint = dvi.getPrintHandler();
        
        //builds the GUI
        build();
        
        //Init printerCombo
        initPrinterCombo();
       
        
        init();
        reset();
        activeListener = true;
        //reset max density
        orientationCombo.setSelectedItem("Portrait");
        storedPrint.setFilmOrientation(jDVPSFilmOrientation.DVPSF_portrait);
        
    }

    /**
     * Initializes the printerCombo from the jDVInterface
     */
    public void initPrinterCombo()
    {
        /////////////////////////////////////////////////
        //fill printerCombo
        ///////////////////////////////////////////////////
        Vector printerList = new Vector();
        int selectedTargetIndex = 0;
        
        int sizeFor = dvi.getNumberOfTargets(jDVPSPeerType.DVPSE_print);
        for (int i = 0; i < sizeFor; i++)
        {
            target = dvi.getTargetID(i, jDVPSPeerType.DVPSE_print);
            if ((dvi.getCurrentPrinter() != null)&&(dvi.getCurrentPrinter().equals(target)))
            {
                selectedTargetIndex = i;
            }
            printerList.addElement(dvi.getTargetDescription(target));
            
        }
        printerCombo.setModel(new DefaultComboBoxModel(printerList));
        
        //Hier mu normalerweise Targetfestgelegt werden.
        if (dvi.getCurrentPrinter() == null ) 
        {
            
            target = dvi.getTargetID(0, jDVPSPeerType.DVPSE_print);
            dvi.setCurrentPrinter(target);
        }
        else target = dvi.getCurrentPrinter();
        {
            
        }
        
    }
    
    
    /**
     * Build the GUI of the PrintPanel.
     * 
     */
    public void build()
    {
        //Contains the PreviewPanel.
        JPanel centerPanel = new JPanel();
        centerPanel.setLayout(new BorderLayout());
        
        //Contains the buttonPanel and the labelPanel.
        JPanel downPanel = new JPanel(new GridLayout(1,1));
        
        //Contains information about the print job
        JPanel labelPanel = new JPanel();
        labelPanel.add(imageLabel);
        labelPanel.setBackground(labelColor);
        downPanel.add(labelPanel);
        
        //Contains the button bar
        JPanel buttonPanel = new JPanel();
        printButton = new CommandJButton("Print", this, ID_PRINT);
        removeButton = new CommandJButton("Clear", this, ID_REMOVE);
        buttonPanel.add(printButton);
        buttonPanel.add(removeButton);
       
        
        
       
        centerPanel.add(downPanel, BorderLayout.SOUTH);
        
        //Init previewPanel
        previewPanel = new PreviewPanel(previewMouseHandler,1,1,storedPrint);
        centerPanel.add(previewPanel,BorderLayout.CENTER);
        
        add(centerPanel, BorderLayout.CENTER);
        
        
        
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.anchor = GridBagConstraints.NORTHWEST;
        
        /////////////////////////////////////////////////////////////
        //Print job settings
        ////////////////////////////////////////////////////////////
        
        //Contains the settings for the print job
        JPanel fPanel = new JPanel();
        JLabel sizeLabel = new JLabel("MMMMMMMMMMMMMMMMMMMM");
        Dimension prefSize = new Dimension(sizeLabel.getPreferredSize().width, sizeLabel.getPreferredSize().height+sizeLabel.getPreferredSize().height/4) ;
        //fPanel.setPreferredSize(prefSize);
        //
        fPanel.setLayout(new GridBagLayout());
        add(new JScrollPane(fPanel), BorderLayout.EAST);
       
        //Contains the layout settings
        JPanel layoutPanel = new JPanel();
        layoutPanel.setLayout(new GridBagLayout());
        layoutPanel.setBorder(new TitledBorder("Layout"));
        
        //Printer
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        layoutPanel.add(new JLabel("Printer"),gbc);
        layoutPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        printerCombo = new CommandJComboBox(this, ID_PRINTER);
        printerCombo.setPreferredSize(prefSize);
        layoutPanel.add(printerCombo,gbc);
        
        //Medium
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        layoutPanel.add(new JLabel("Medium"),gbc);
        layoutPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        mediumCombo = new CommandJComboBox(this, ID_MEDIUM);
        mediumCombo.setPreferredSize(prefSize);
        layoutPanel.add(mediumCombo,gbc);
        
        //film Size
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        layoutPanel.add(new JLabel("Film Size"),gbc);
        layoutPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        filmSizeCombo = new CommandJComboBox(this, ID_FILMSIZE);
        filmSizeCombo.setPreferredSize(prefSize);
        layoutPanel.add(filmSizeCombo,gbc);
        
        //Orientation
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        layoutPanel.add(new JLabel("Orientation"),gbc);
        layoutPanel.add(Box.createHorizontalStrut(10),gbc);
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        orientationCombo = new CommandJComboBox(this, ID_ORIENTATION);
        orientationCombo.setPreferredSize(prefSize);
        
        layoutPanel.add(orientationCombo,gbc);
        Vector orientationList = new Vector();
        orientationList.addElement(new String("Portrait"));
        orientationList.addElement(new String("Landscape"));
        orientationList.addElement(new String("<Default>"));
        orientationCombo.setModel(new DefaultComboBoxModel(orientationList));
        
        
        //Priority
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        layoutPanel.add(new JLabel("Priority"),gbc);
        layoutPanel.add(Box.createHorizontalStrut(10),gbc);
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        priorityCombo = new CommandJComboBox(this, ID_PRIORITY);
        priorityCombo.setPreferredSize(prefSize);
        
        layoutPanel.add(priorityCombo,gbc);
        Vector priorityList = new Vector();
        priorityList.addElement(new String("HIGH"));
        priorityList.addElement(new String("MED"));
        priorityList.addElement(new String("LOW"));
        priorityList.addElement(new String("<Default>"));
        priorityCombo.setModel(new DefaultComboBoxModel(priorityList));
        
        
        //Layout
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        layoutPanel.add(new JLabel("Layout"),gbc);
        layoutPanel.add(Box.createHorizontalStrut(10),gbc);
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        layoutCombo = new CommandJComboBox(this, ID_LAYOUT);
        layoutCombo.setPreferredSize(prefSize);
        layoutPanel.add(layoutCombo,gbc);
        
        //Copies
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        layoutPanel.add(new JLabel("Copies"),gbc);
        layoutPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        copiesText = new CommandJTextField(2,this, ID_COPIES);
        copiesText.setDocument(new IntegerDocument(1));
        layoutPanel.add(copiesText,gbc);
        
        /////////////////////////////////
        //Contains the additional layout settings
        //////////////////////////////////
        JPanel addPanel = new JPanel();
        addPanel.setBorder(new TitledBorder("Additional Layout Options"));
        
        
        JPanel addLeftPanel = new JPanel(new GridBagLayout());
        
        //Magnification
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        addLeftPanel.add(new JLabel("Magnification"),gbc);
        addLeftPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        magnificationCombo = new CommandJComboBox(this, ID_MAGNIFICATION);
        magnificationCombo.setPreferredSize(prefSize);
        addLeftPanel.add(magnificationCombo,gbc);
        
        //Smoothing
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        addLeftPanel.add(new JLabel("Smoothing"),gbc);
        addLeftPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        smoothingCombo = new CommandJComboBox(this, ID_SMOOTHING);
        smoothingCombo.setPreferredSize(prefSize);
        addLeftPanel.add(smoothingCombo,gbc);
                
        //Configuration
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        addLeftPanel.add(new JLabel("Configuration"),gbc);
        addLeftPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        configurationCombo = new CommandJComboBox(this, ID_CONFIGURATION);
        configurationCombo.setPreferredSize(prefSize);
        
        addLeftPanel.add(configurationCombo,gbc);
        
        //Resolution
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        addLeftPanel.add(new JLabel("Resolution"),gbc);
        addLeftPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        resolutionCombo = new CommandJComboBox(this, ID_RESOLUTION);
        resolutionCombo.setPreferredSize(prefSize);
        addLeftPanel.add(resolutionCombo,gbc);
        
        
        
        JPanel addRightPanel = new JPanel(new GridBagLayout());
        
        //Trim
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        addLeftPanel.add(new JLabel("Trim"),gbc);
        addLeftPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        trimCombo = new CommandJComboBox(this, ID_TRIM);
        trimCombo.setPreferredSize(prefSize);
        addLeftPanel.add(trimCombo,gbc);
        
        //Cropping
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        addLeftPanel.add(new JLabel("Cropping"),gbc);
        addLeftPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        croppingCombo = new CommandJComboBox(this, ID_CROPPING);
        croppingCombo.setPreferredSize(prefSize);
        addLeftPanel.add(croppingCombo,gbc);
        
        //Border
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        addLeftPanel.add(new JLabel("Border"),gbc);
        addLeftPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        borderCombo = new CommandJComboBox(this, ID_BORDER);
        borderCombo.setPreferredSize(prefSize);
        addLeftPanel.add(borderCombo,gbc);
        
        //Empty Image
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        addLeftPanel.add(new JLabel("Empty Image"),gbc);
        addLeftPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        emptyImageCombo = new CommandJComboBox(this, ID_EMPTYIMAGE);
        emptyImageCombo.setPreferredSize(prefSize);
        addLeftPanel.add(emptyImageCombo,gbc);
        
        //MinDesity
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        addLeftPanel.add(new JLabel("Min Density"),gbc);
        addLeftPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        minDensityCombo = new CommandJComboBox(this, ID_MINDENSITY);
        minDensityCombo.setPreferredSize(prefSize);
        addLeftPanel.add(minDensityCombo,gbc);
        
        //MaxDesity
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        addLeftPanel.add(new JLabel("Max Density"),gbc);
        addLeftPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        maxDensityCombo = new CommandJComboBox(this, ID_MAXDENSITY);
        maxDensityCombo.setPreferredSize(prefSize);
        addLeftPanel.add(maxDensityCombo,gbc);
        addPanel.add(addLeftPanel);
        
        //////////////////////////////////////////////
        //Contains the presentation lut settings
        ////////////////////////////////////////
        JPanel pLutPanel = new JPanel();
        pLutPanel.setLayout(new GridBagLayout());
        pLutPanel.setBorder(new TitledBorder("Presentation LUT Options"));
        /*
        //Presentation LUT
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        pLutPanel.add(new JLabel("Presentation LUT"),gbc);
        pLutPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        presentationLutCombo = new CommandJComboBox(this, ID_PRESENTATIONLUT);
        pLutPanel.add(presentationLutCombo,gbc);
        */
        //Illumination
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        pLutPanel.add(new JLabel("Illumination (cd/m^2)"),gbc);
        pLutPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        illuminationText = new CommandJTextField(10,this, ID_ILLUMINATION);
        illuminationText.setDocument(new IntegerDocument(10));
        pLutPanel.add(illuminationText,gbc);
        
        //Illumination
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        pLutPanel.add(new JLabel("Reflection (cd/m^2)"),gbc);
        pLutPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        reflectionText = new CommandJTextField(10,this, ID_REFLECTION);
        reflectionText.setDocument(new IntegerDocument(10));
        pLutPanel.add(reflectionText,gbc);
        
        GridBagConstraints fGbc = new GridBagConstraints();
        fGbc.anchor = GridBagConstraints.NORTHWEST;
        fGbc.gridwidth = 1;
        fGbc.gridheight = 1;
        
        fGbc.gridx = GridBagConstraints.REMAINDER;
        fGbc.fill = GridBagConstraints.HORIZONTAL;
        
        
        ///////////////////////////////
        //
        /////////////////////////////////////////////////////
        
        
        annPanel.setLayout(new GridBagLayout());
        annPanel.setBorder(new TitledBorder("Annotation"));
        
        
        annOnRadioButton = new CommandJRadioButton("on", false, this, ID_ANNON);
        annOffRadioButton = new CommandJRadioButton("off", true, this, ID_ANNOFF);
        ButtonGroup bg = new ButtonGroup();
        bg.add(annOnRadioButton);
        bg.add(annOffRadioButton);
        
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        annPanel.add(annOffRadioButton,gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        annPanel.add(annOnRadioButton,gbc);
        
        
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        annPanel.add(new JLabel("   "),gbc);
        annPanel.add(Box.createHorizontalStrut(10),gbc);
        
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        annPanel.add(new JLabel("Text:"),gbc);
        annPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        gbc.weightx = 1.0;
        annotationText = new JTextField();
        annPanel.add(annotationText,gbc);
        
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        annPanel.add(new JLabel("   "),gbc);
        annPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        annDateCheckBox = new JCheckBox("Date/Time");
        annPanel.add(annDateCheckBox,gbc);
        
        
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        annPanel.add(new JLabel("   "),gbc);
        annPanel.add(Box.createHorizontalStrut(10),gbc);
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        annPrinterNameCheckBox = new JCheckBox("Printer Name");
        annPanel.add(annPrinterNameCheckBox,gbc);
        
        gbc.fill = GridBagConstraints.NONE;
        gbc.weightx = 0.0;
        gbc.gridwidth = 1;
        annPanel.add(new JLabel("   "),gbc);
        annPanel.add(Box.createHorizontalStrut(10),gbc);
                
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridwidth = GridBagConstraints.REMAINDER;
        annIllCheckBox = new JCheckBox("Illumination/Reflection");
        annPanel.add(annIllCheckBox,gbc);
       

    
        
        
        
        fPanel.add(layoutPanel,fGbc);
        fPanel.add(addPanel,fGbc);
        fPanel.add(pLutPanel,fGbc);
        fPanel.add(annPanel,fGbc);
        fPanel.add(buttonPanel,fGbc);
            
    }

    /**
     * Initializes the widgets with values form the DVIInterface
     */
    public void init()
    {
        
        
        ///////////////////////////////
        //Fill medium for current Printer
        /////////////////////////////////
        Vector mediumList = new Vector();
        int forSize = dvi.getTargetPrinterNumberOfMediumTypes(target);
        for (int i = 0; i < forSize;i++)
        {
            String t = dvi.getTargetPrinterMediumType(target, i );
            mediumList.addElement(t);
        }
        mediumList.addElement(new String("<Default>"));
        mediumCombo.setModel(new DefaultComboBoxModel(mediumList));
        
        
        
        ///////////////////////////////
        //Fill Film size for current Printer
        /////////////////////////////////
        Vector filmSizeList = new Vector();
        
        forSize = dvi.getTargetPrinterNumberOfFilmSizeIDs(target);
        
        for (int i = 0; i < forSize;i++)
        {
            String t = dvi.getTargetPrinterFilmSizeID(target, i );
            filmSizeList.addElement(t);
        }
        
        filmSizeList.addElement(new String("<Default>"));
        filmSizeCombo.setModel(new DefaultComboBoxModel(filmSizeList));
        
        ///////////////////////////////
        //Fill Film size for current Printer
        /////////////////////////////////
        ///////////////////////////////
        //Fill Magnification for current Printer
        /////////////////////////////////
        Vector magnificationList = new Vector();
        
        forSize = dvi.getTargetPrinterNumberOfMagnificationTypes(target);
        for (int i = 0; i < forSize;i++)
        {
            String t = dvi.getTargetPrinterMagnificationType(target, i );
            magnificationList.addElement(t);
        }
        magnificationList.addElement(new String("<Default>"));
        magnificationCombo.setModel(new DefaultComboBoxModel(magnificationList));
       
        
        Vector smoothingList = new Vector();
        forSize = dvi.getTargetPrinterNumberOfSmoothingTypes(target);
        for (int i = 0; i < forSize;i++)
        {
            String t = dvi.getTargetPrinterSmoothingType(target, i );
            smoothingList.addElement(t);
                
        }
        smoothingList.addElement(new String("<Default>"));
        
        ///////////////////////////////
        //Fehler getTargetPrinterConfigurationSetting
        /////////////////////////////////
        Vector configurationList = new Vector();
       
        forSize = dvi.getTargetPrinterNumberOfConfigurationSettings(target);
        for (int i = 0; i < forSize;i++)
        {
            String t = dvi.getTargetPrinterConfigurationSetting(target, i );
            configurationList.addElement(t);
        }
        configurationList.addElement(new String("<Default>"));
        configurationCombo.setModel(new DefaultComboBoxModel(configurationList));

        ///////////////////////////////
        //Resolution
        /////////////////////////////////
        Vector resolutionList = new Vector();
        
        forSize = dvi.getTargetPrinterNumberOfPrinterResolutionIDs(target);
        for (int i = 0; i < forSize;i++)
        {
            String t = dvi.getTargetPrinterResolutionID(target, i );
            resolutionList.addElement(t);
        }
        resolutionList.addElement(new String("<Default>"));
        resolutionCombo.setModel(new DefaultComboBoxModel(resolutionList));

        ///////////////////////////////
        //Trim
        /////////////////////////////////
        Vector trimList = new Vector();
        
        if (dvi.getTargetPrinterSupportsTrim(target))
        {
            trimList.addElement(new String("On"));
            trimList.addElement(new String("Off"));
            
        }
        trimList.addElement(new String("<Default>"));
        trimCombo.setModel(new DefaultComboBoxModel(trimList));
        
        ///////////////////////////////
        //crop
        /////////////////////////////////
        Vector cropList = new Vector();
        
        if (dvi.getTargetPrinterSupportsDecimateCrop(target))
        {
            cropList.addElement(new String("DECIMATE"));
            cropList.addElement(new String("CROP"));
            cropList.addElement(new String("FAIL"));
            
        }
        cropList.addElement(new String("<Default>"));
        croppingCombo.setModel(new DefaultComboBoxModel(cropList));
        
        ///////////////////////////////
        //Border Error
        /////////////////////////////////
        
        Vector borderList = new Vector();
        forSize = dvi.getTargetPrinterNumberOfBorderDensities(target);
        for (int i = 0; i < forSize;i++)
        {
            String t = dvi.getTargetPrinterBorderDensity(target, i );
            borderList.addElement(t);
        }
        borderList.addElement(new String("<Default>"));
        borderCombo.setModel(new DefaultComboBoxModel(borderList));
        
        
        ///////////////////////////////
        //EmptyImages
        /////////////////////////////////
        
        Vector emptyList = new Vector();
        
        forSize = dvi.getTargetPrinterNumberOfEmptyImageDensities(target);
        for (int i = 0; i < forSize;i++)
        {
            String t = dvi.getTargetPrinterEmptyImageDensity(target, i );
            emptyList.addElement(t);
        }
        emptyList.addElement(new String("<Default>"));
        emptyImageCombo.setModel(new DefaultComboBoxModel(emptyList));
        
        ///////////////////////////////
        //Min Density
        /////////////////////////////////
        
        Vector minDensityList = new Vector();
        
        forSize = dvi.getTargetPrinterNumberOfMinDensities(target);
        
        
        for (int i = 0; i < forSize;i++)
        {
              
            
            minDensityList.addElement(dvi.getTargetPrinterMinDensity(target, i ));
        }
        minDensityList.addElement(new String("<Default>"));
        minDensityCombo.setModel(new DefaultComboBoxModel(minDensityList));
        
        ///////////////////////////////
        //Min Density
        /////////////////////////////////
        
        Vector maxDensityList = new Vector();
        
        forSize = dvi.getTargetPrinterNumberOfMaxDensities(target);
        
        
        for (int i = 0; i < forSize;i++)
        {
              
            
            maxDensityList.addElement(dvi.getTargetPrinterMaxDensity(target, i ));
        }
        maxDensityList.addElement(new String("<Default>"));
        maxDensityCombo.setModel(new DefaultComboBoxModel(maxDensityList));
        ///////////////////////////////
        //Presntation LUT
        /////////////////////////////////
       /* 
        Vector lutList = new Vector();
        if (dvi.getTargetPrinterSupportsPresentationLUT(target))
        {
            if (dvi.getTargetPrinterSupports12BitTransmission(target))
            {
                lutList.addElement(new String("Identity"));
            }
            else
            {
                forSize = dvi.getNumberOfLUTs();
                for (int i = 0; i < forSize;i++)
                {
                    lutList.addElement(dvi.getLUTDescription(dvi.getLUTID(i)));
                }
                
            }
        }
        lutList.addElement(new String("<Default>"));
        presentationLutCombo.setModel(new DefaultComboBoxModel(lutList));
        */ 
        illuminationText.setText(new Integer(dvi.getPrintIllumination()).toString());
        reflectionText.setText(new Integer(dvi.getPrintReflectedAmbientLight()).toString());
       
    }

    /**
     * Initialize the smoothingCombo.
     */
    public void initSmoothing()
    {
        Vector smoothingList = new Vector();
        if ((storedPrint.getMagnificationType() != null) &&storedPrint.getMagnificationType().equals("CUBIC"))
        {
            int forSize = dvi.getTargetPrinterNumberOfSmoothingTypes(target);
            for (int i = 0; i < forSize;i++)
            {
                String t = dvi.getTargetPrinterSmoothingType(target, i );
                smoothingList.addElement(t);
                
            }
            
        }
        smoothingList.addElement(new String("<Default>"));
        smoothingCombo.setModel(new DefaultComboBoxModel(smoothingList));
        smoothingCombo.setSelectedIndex(smoothingList.size()-1);
        storedPrint.setSmoothingType(new String(""));
            
        
        
    }

    /**
     * Handles the action events from Buttons and ComboBoxes
     * 
     * @param ID ID of the clicked widget
     */
    public void buttonClicked (int ID)
    {
        if (activeListener)
        {
            switch (ID)
            {
               
                case ID_PRINT: 
                            if (annOffRadioButton.isSelected())
                            {
                                dvi.setActiveAnnotation(false);
                                System.out.println("Print off");
                            }
                            else
                            {
                                dvi.setActiveAnnotation(true);
                                dvi.setPrependDateTime(annDateCheckBox.isSelected());
                                dvi.setAnnotationText(annotationText.getText());
                                dvi.setPrependLighting(annIllCheckBox.isSelected());
                                dvi.setPrependPrinterName(annPrinterNameCheckBox.isSelected());
                                System.out.println("Print on");
                                
                            }
                            
                            
                            int status = dvi.spoolPrintJob(true);
                            System.out.println("Print: spoolPrintJob- start");
                            previewPanel.updatePrintPreview();
                            setLabel();
                            break;
                
                case ID_PRINTER:
                            target = dvi.getTargetID(printerCombo.getSelectedIndex(), jDVPSPeerType.DVPSE_print);
                            dvi.setCurrentPrinter(target);
                            activeListener = false;
                            init();
                            reset();
                            activeListener = true;
                            //previewPanel.updatePrintPreview();
                            break;
                            
                case ID_REMOVE:
                            storedPrint.deleteMultipleImages(storedPrint.getNumberOfImages());
                            previewPanel.updatePrintPreview();
                            setLabel();
                            break;
                            
                case ID_MEDIUM: 
                            if ( mediumCombo.getSelectedIndex() >= dvi.getTargetPrinterNumberOfMediumTypes(target)) dvi.setPrinterMediumType(new String(""));
                            else dvi.setPrinterMediumType((String)mediumCombo.getSelectedItem());
                            break;
                         
                case ID_FILMSIZE: 
                            if ( filmSizeCombo.getSelectedIndex() >= dvi.getTargetPrinterNumberOfFilmSizeIDs(target)) storedPrint.setFilmSizeID(new String(""));
                            else storedPrint.setFilmSizeID((String)filmSizeCombo.getSelectedItem());
                            break;
                case ID_PRIORITY: 
                            if ( priorityCombo.getSelectedItem().equals("<Default>")) dvi.setPrinterPriority(new String(""));
                            else dvi.setPrinterPriority((String)priorityCombo.getSelectedItem());
                            break;
                            
                case ID_ORIENTATION:
                            boolean hasChanged = false;
                            if ( orientationCombo.getSelectedItem().equals("<Default>")) 
                            {
                                storedPrint.setFilmOrientation(jDVPSFilmOrientation.DVPSF_default);
                                if (!currentOrientationIsPortrait )
                                {
                                    currentOrientationIsPortrait = true;
                                    hasChanged = true;
                                }
                            }
                            else if ( orientationCombo.getSelectedItem().equals("Landscape"))
                            {
                                storedPrint.setFilmOrientation(jDVPSFilmOrientation.DVPSF_landscape);
                                if (currentOrientationIsPortrait )
                                {
                                    currentOrientationIsPortrait = false;
                                    hasChanged = true;
                                }
                            }
                            else if ( orientationCombo.getSelectedItem().equals("Portrait"))
                            {
                                storedPrint.setFilmOrientation(jDVPSFilmOrientation.DVPSF_portrait);
                                if (!currentOrientationIsPortrait )
                                {
                                    currentOrientationIsPortrait = true;
                                    hasChanged = true;
                                }
                            }
                            
                            if (hasChanged)
                            {
                                
                                if (orientationCombo.getSelectedIndex()== 1) previewPanel.setOrientation(false);
                                else previewPanel.setOrientation(true);
                                
                                long help = printerCurrentRows;
                                printerCurrentRows= printerCurrentCols ;
                                printerCurrentCols = help;
                                setLayoutCombo();
                                
                            }
                            break;
                          
                case ID_MAGNIFICATION: 
                            if ( magnificationCombo.getSelectedIndex() >= dvi.getTargetPrinterNumberOfMagnificationTypes(target)) storedPrint.setMagnificationType(new String(""));
                            else storedPrint.setMagnificationType((String)magnificationCombo.getSelectedItem());
                            initSmoothing();
                            break;
                             
                case ID_SMOOTHING: 
                            if ( smoothingCombo.getSelectedIndex() >= dvi.getTargetPrinterNumberOfSmoothingTypes(target)) storedPrint.setSmoothingType(new String(""));
                            else storedPrint.setSmoothingType((String)smoothingCombo.getSelectedItem());
                            break;
            
                case ID_RESOLUTION: 
                            if ( resolutionCombo.getSelectedIndex() >= dvi.getTargetPrinterNumberOfPrinterResolutionIDs(target)) storedPrint.setResolutionID(new String(""));
                            else storedPrint.setResolutionID((String)resolutionCombo.getSelectedItem());
                            break;
                 
                case ID_CONFIGURATION: 
                            if ( configurationCombo.getSelectedIndex() >= dvi.getTargetPrinterNumberOfConfigurationSettings(target)) storedPrint.setConfigurationInformation(new String(""));
                            else storedPrint.setConfigurationInformation((String)configurationCombo.getSelectedItem());
                            break;
                
                case ID_TRIM: 
                            if (dvi.getTargetPrinterSupportsTrim(target))
                            {
                                if (trimCombo.getSelectedIndex() == 0) storedPrint.setTrim(jDVPSTrimMode.DVPSH_trim_on);
                                if (trimCombo.getSelectedIndex() == 1) storedPrint.setTrim(jDVPSTrimMode.DVPSH_trim_off);
                                if (trimCombo.getSelectedIndex() == 2) storedPrint.setTrim(jDVPSTrimMode.DVPSH_default);
                            }
                            break;
                case ID_CROPPING: 
                            if (dvi.getTargetPrinterSupportsDecimateCrop(target))
                            {
                                if (croppingCombo.getSelectedIndex() == 0) storedPrint.setRequestedDecimateCropBehaviour(jDVPSDecimateCropBehaviour.DVPSI_decimate);
                                if (croppingCombo.getSelectedIndex() == 1) storedPrint.setRequestedDecimateCropBehaviour(jDVPSDecimateCropBehaviour.DVPSI_crop);
                                if (croppingCombo.getSelectedIndex() == 2) storedPrint.setRequestedDecimateCropBehaviour(jDVPSDecimateCropBehaviour.DVPSI_fail);
                                if (croppingCombo.getSelectedIndex() == 3) storedPrint.setRequestedDecimateCropBehaviour(jDVPSDecimateCropBehaviour.DVPSI_default);
                            }
                            break;
                case ID_BORDER: 
                            if ( borderCombo.getSelectedIndex() >= dvi.getTargetPrinterNumberOfBorderDensities(target)) storedPrint.setBorderDensity(new String(""));
                            else storedPrint.setBorderDensity((String)borderCombo.getSelectedItem());
                            break;
               
                case ID_EMPTYIMAGE: 
                            if ( emptyImageCombo.getSelectedIndex() >= dvi.getTargetPrinterNumberOfEmptyImageDensities(target)) storedPrint.setEmtpyImageDensity(new String(""));
                            else storedPrint.setEmtpyImageDensity((String)emptyImageCombo.getSelectedItem());
                            break;
                case ID_MINDENSITY: 
                            if ( minDensityCombo.getSelectedIndex() >= dvi.getTargetPrinterNumberOfMinDensities(target)) storedPrint.setMinDensity(new String(""));
                            else storedPrint.setMinDensity((String)minDensityCombo.getSelectedItem());
                            break;
                case ID_MAXDENSITY: 
                            if ( maxDensityCombo.getSelectedIndex() >= dvi.getTargetPrinterNumberOfMaxDensities(target)) storedPrint.setMaxDensity(new String(""));
                            else storedPrint.setMaxDensity((String)maxDensityCombo.getSelectedItem());
                            break;
                case ID_LAYOUT:
                            int index = layoutCombo.getSelectedIndex();
                            printerCurrentRows = dvi.getTargetPrinterPortraitDisplayFormatRows(target, index );
                            printerCurrentCols = dvi.getTargetPrinterPortraitDisplayFormatColumns(target, index );
                                //set value
                            storedPrint.setImageDisplayFormat(printerCurrentCols, printerCurrentRows);
                                    
                            //change previewPanel
                            previewPanel.setRowsCols((int) printerCurrentRows,(int)printerCurrentCols);
                                    
                                    
                            setLabel();
                            
                            break;
               
                            
            }
        }
    }
    public   void buttonClicked (int ID, boolean selected)
    {
            switch (ID)
            {
                case ID_ANNOFF: 
                        annotationText.setEnabled(false);
                        annDateCheckBox.setEnabled(false);
                        annPrinterNameCheckBox.setEnabled(false);
                        annIllCheckBox.setEnabled(false);
                        
                        break;
                        
                case ID_ANNON: 
                        annotationText.setEnabled(true);
                        annDateCheckBox.setEnabled(true);
                        annPrinterNameCheckBox.setEnabled(true);
                        annIllCheckBox.setEnabled(true);
                        break;
            }
                    
    }

    /**
     * Handles the ActionEvents and FocusLostEvents from TextFields
     * 
     * @param ID ID of the fired widget
     * @param text The new text
     */
    public void setText(int ID, String text)
    {
        if (activeListener)
        {
            switch (ID)
            {
                    
                case ID_ILLUMINATION: 
                                if (text.trim().equals(""))
                                {
                                    JOptionPane.showMessageDialog(null,"Value must be > 1");
                                    illuminationText.setText("1");
                                        
                                }
                                
                                dvi.setPrintIllumination(new Integer(text).intValue());
                                break;
                case ID_REFLECTION: 
                                if (text.trim().equals(""))
                                {
                                    JOptionPane.showMessageDialog(null,"Value must be > 1");
                                    reflectionText.setText("1");
                                        
                                }
                                dvi.setPrintReflectedAmbientLight(new Integer(text).intValue());
                                break;
               case ID_COPIES:
                                if (text.equals(""))dvi.setPrinterNumberOfCopies(0);
                                else 
                                {
                                    int copies = (new Integer(text)).intValue();
                                    if (copies < 1) 
                                    {
                                        JOptionPane.showMessageDialog(null,"Value must be > 1");
                                        copiesText.setText("1");
                                        dvi.setPrinterNumberOfCopies(1);
                                    }
                                    else 
                                    {
                                        if (copies > 9)
                                        {
                                            JOptionPane.showMessageDialog(null,"Value must be <= 9");
                                            copiesText.setText("9");
                                             dvi.setPrinterNumberOfCopies(9);
                                        }
                                        else 
                                        {
                                            dvi.setPrinterNumberOfCopies(copies);
                                        }
                                    }
                                }
                                break;
               
            }
        }
    }

    /**
     * resets the settings for the print job.
     * Necessary if changing the current printer.
     */
    public void reset()
    {
        
        
        storedPrint = dvi.getPrintHandler();
        previewPanel.setStoredPrint(storedPrint);
        
        
        storedPrint.newPrinter();
            
        
        if (!dvi.getTargetPrinterSupportsAnnotation(dvi.getCurrentPrinter()))
        {
            annOffRadioButton.setSelected(true);
            annOnRadioButton.setEnabled(false);
            annotationText.setEnabled(false);
            annDateCheckBox.setEnabled(false);
            annPrinterNameCheckBox.setEnabled(false);
            annIllCheckBox.setEnabled(false);
        }
        else annOnRadioButton.setEnabled(true);
            
        
        copiesText.setText("1");
        dvi.setPrinterNumberOfCopies(new Integer(copiesText.getText()).intValue());
        
        //reset medium type
        dvi.setPrinterMediumType(new String(""));
        mediumCombo.setSelectedIndex(mediumCombo.getItemCount()-1);
        
        //reset filmSize
        //storedPrint.setFilmSizeID(new String(""));
        filmSizeCombo.setSelectedIndex(filmSizeCombo.getItemCount()-1);
        
        
        //reset magnification type
        //storedPrint.setMagnificationType(new String(""));
        magnificationCombo.setSelectedIndex(magnificationCombo.getItemCount()-1);
        
        //reset smoothing
        initSmoothing();
        
        
        //reset filmSize
        //storedPrint.setFilmSizeID(new String(""));
        priorityCombo.setSelectedIndex(priorityCombo.getItemCount()-1);
        
        //reset configuration
        //storedPrint.setConfigurationInformation(new String(""));
        configurationCombo.setSelectedIndex(configurationCombo.getItemCount()-1);
        
        //reset resolution
        //resolutionCombo.setSelectedIndex(resolutionCombo.getItemCount()-1);
        storedPrint.setResolutionID(new String(""));
        
        //reset trim
        //storedPrint.setTrim(jDVPSTrimMode.DVPSH_default);
        trimCombo.setSelectedIndex(trimCombo.getItemCount()-1);
        
        //reset requested decimate crop behaviour
        //storedPrint.setRequestedDecimateCropBehaviour(jDVPSDecimateCropBehaviour.DVPSI_default);
        croppingCombo.setSelectedIndex(croppingCombo.getItemCount()-1);
        
        //reset border
        borderCombo.setSelectedIndex(borderCombo.getItemCount()-1);
        storedPrint.setBorderDensity(new String(""));
        
        //reset empty image
        emptyImageCombo.setSelectedIndex(emptyImageCombo.getItemCount()-1);
        storedPrint.setEmtpyImageDensity(new String(""));
        
        //reset min density
        minDensityCombo.setSelectedIndex(minDensityCombo.getItemCount()-1);
        storedPrint.setMinDensity(new String(""));
        
        //reset max density
        maxDensityCombo.setSelectedIndex(maxDensityCombo.getItemCount()-1);
        storedPrint.setMaxDensity(new String(""));
        
        
        setLayoutCombo();
    }

    /**
     * Handle  DSEvents from other components. 
     * 
     * @param e
     */
    public boolean processPrint(DSEvent e)
    {
       //Notification about receiveing and new print hardcopy.
       if (e instanceof PrintEvent)
       {
           //inset a new image preview into the PreviewPanel.
           previewPanel.updatePrintPreview();
           setLabel();
       }
        return false;
    }

    /**
     * Fills the imageLabel.
     */
    public void setLabel()
    {
        int pagesInJob = storedPrint.getNumberOfImages()/(int)(printerCurrentRows*printerCurrentCols);
         
        if (storedPrint.getNumberOfImages()%(int)(printerCurrentRows*printerCurrentCols)>0)pagesInJob++;
        imageLabel.setText("Images in Queue: " + storedPrint.getNumberOfImages()+ ", Pages : " + pagesInJob + " from " + pagesInJob);
    }

    /**
     * Gets the current jDVPSStoredPrint
     * 
     * @return The current jDVPSStoredPrint
     */
    public jDVPSStoredPrint getStored()
    {
        return  storedPrint;
    }


    /**
     * Gets the current jDVInterface
     * 
     * @return The current jDVInterface
     */
    public jDVInterface getDvi()
    {
        return dvi;
    }
     public void setLayoutCombo()
     {
         target = dvi.getCurrentPrinter();  
        activeListener = false; 
         boolean portrait = true;
         
         if (orientationCombo.getSelectedItem().equals("Landscape"))portrait = false;
        
        
        ///////////////////////////////
        //Fill Film size for current Printer
        /////////////////////////////////
        Vector layoutList = new Vector();
       int  forSize = dvi.getTargetPrinterNumberOfPortraitDisplayFormats(target);
       String t = null;
        if (forSize == 0 ) 
        {
            JOptionPane.showMessageDialog(null,"Missing Printer Layout in Configuration for Printer: " +target);
            System.exit(0);
        }
        for (int i = 0; i < forSize;i++)
        {
            if (portrait) t  = dvi.getTargetPrinterPortraitDisplayFormatRows(target, i )+ "/" + dvi.getTargetPrinterPortraitDisplayFormatColumns(target, i );
            else  t  = dvi.getTargetPrinterPortraitDisplayFormatColumns(target, i )+ "/" + dvi.getTargetPrinterPortraitDisplayFormatRows(target, i );
            layoutList.addElement(t);
        }
        
        layoutCombo.setModel(new DefaultComboBoxModel(layoutList));
    
    
    
         
        
        int cols = 1;
        int rows = 1;;
        int bestIndex= 0;
        int nextCols=1;
        int nextRows=1;
        
        for (int i = 0; i < forSize;i++)
        {
            nextCols = dvi.getTargetPrinterPortraitDisplayFormatColumns(target, i );
            nextRows  = dvi.getTargetPrinterPortraitDisplayFormatRows(target, i );
            if (portrait) 
            {
                if ((nextCols <= printerCurrentCols) &&(nextRows <= printerCurrentRows)
                    &&(nextCols >= cols)&&(nextRows >= rows))
                {
                    bestIndex = i;
                    cols = nextCols;
                    rows = nextRows;
                }
            }
            else
            {
                if ((nextCols <= printerCurrentRows) &&(nextRows <= printerCurrentCols)
                    &&(nextCols >= rows)&&(nextRows >= cols))
                {
                    bestIndex = i;
                    cols = nextRows;
                    rows = nextCols;
                }
                
            }
        }
         
         printerCurrentCols = cols ;
         printerCurrentRows = rows;
         layoutCombo.setSelectedIndex(bestIndex);
        storedPrint.setImageDisplayFormat(printerCurrentCols, printerCurrentRows);
                                    
        //change previewPanel
        previewPanel.setRowsCols((int) printerCurrentRows,(int)printerCurrentCols);
                                    
        setLabel();
         activeListener = true; 
        
     }
    /**
     * Deletes the image with the specified index form the print job
     * 
     * @param index Index of the specified image
     */
    public void deleteImage(int index)
    {
        storedPrint.deleteImage(index);
        previewPanel.updatePrintPreview();
        setLabel();
    }
}
/*
 *  CVS Log
 *  $Log: PrintPanel.java,v $
 *  Revision 1.2  2000/03/17 14:07:55  kleber
 *  chg: Layout texts on GUI
 *
 *  Revision 1.1.1.1  2000/03/13 14:39:52  kleber
 *  init log for first free release
 *
*/
