/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: kleber $
 *  Last update : $Date: 2000/03/13 14:39:52 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package jToolkit.gui;

import java.awt.*;
import java.awt.event.*;

/**
 * The CommandAWTButton extends the normal Button with an automatic command
 * call when the button is pressed. 
 *
 * Usage:
 * 
 * class FooClass extends Panel implements CommandButtonListener
 * {
 *  final int IDOK = 1;
 *  final int IDCANCEL = 2;
 *
 *  void Constructor ()
 *  {
 *      CommandAWTButton ok = new CommandAWTButton ("OK", this, IDOK);
 *      CommandAWTButton cancel = new CommandAWTButton ("Cancel", this, IDCANCEL);
 *      add (ok);
 *      add (cancel);
 *  }
 * 
 *  void ButtonClicked (int ID);
 *  {
 *      if (ID == IDOK) doOK(); // OK pressed
 *      if (ID == IDCANCEL) doCancel(); // Cancel pres
 *  }
 * } 
 *
 * @author Andreas Schroeter
 * @since 30.03.
*/
public class CommandAWTButton extends Button implements ActionListener
{
    private int ID;
    private CommandButtonListener cbl;

    public CommandAWTButton (String label, CommandButtonListener cbl, int ID)
    {
        super (label);
        this.ID = ID;
	  this.cbl = cbl;
        addActionListener (this);
    }

    public CommandAWTButton (CommandButtonListener cbl, int ID)
    {
   	    this.cbl = cbl;
        this.ID = ID;
    }
    
    public void actionPerformed(ActionEvent e)
    {
        if (e.getSource() == this) cbl.buttonClicked (ID);
    }
}
/*
 *  CVS Log
 *  $Log: CommandAWTButton.java,v $
 *  Revision 1.1.1.1  2000/03/13 14:39:52  kleber
 *  init log for first free release
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
    