/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: kleber $
 *  Last update : $Date: 2000/03/13 14:39:52 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package viewer.gui;

import java.awt.*;
import java.awt.image.*;

import javax.swing.border.*;
import java.awt.event.*;
import java.util.*;
import javax.swing.*;

import viewer.main.*;
import viewer.presentation.*;
import viewer.controller.*;
import viewer.paint.*;
import main.*;
import jToolkit.gui.*;
import J2Ci.*;

/**
* This class contains the main panel of the image viewer. All other 
* components are integrated in this panel.
* 
* @author Klaus Kleber
* @since 30.04.1999
*/
public class MainImageViewerPanel extends JPanel implements MainListener
{

    
    public JFrame parent;
    
	/**
	 * @since 30.04.1999
	 */
	public ScreenImageHandler screenImageHandler;

    private ScrollListener scrollListener = new ScrollListener();
    
    private FunctionPanel functionPanel;
    
    private String functionPanelOrientation = BorderLayout.NORTH;

    /**
     * Contains the parentFrame of this Panel
     * 
     * @since 30.04.1999
     */
     JScrollBar heightScrollbar;
     JScrollBar widthScrollbar;
     ImageCanvas imageCanvas;

    
	JPanel scroll = new JPanel();
    /**
     * Constructs a new object.
     * 
     * @param presentationStateGraphicsHandler Contains the current PresentationStateGraphicsHandler.
     * @param parentFrame Contains the parent frame of this Panel
     * @param sl Contains reference of a status bar
     * @since 30.04.1999
     */
    public  MainImageViewerPanel(PresentationStateGraphicsHandler presentationStateGraphicsHandler,Hashtable config, JFrame parent)
    {
         super();
         this.parent = parent;
           setBackground(Color.black);
		   
		   Controller.instance().addMainListener(this);
		   //Init screenImageHandler
		   screenImageHandler = new ScreenImageHandler(this,presentationStateGraphicsHandler, config);
		   setBackground(Color.lightGray);
		   setLayout(new BorderLayout(5,5));
           //setFont(MainContext.instance().getUsedFont());
	       
            
            scroll.setLayout(new BorderLayout());
            heightScrollbar = new JScrollBar(JScrollBar.VERTICAL);
            scroll.add(heightScrollbar, BorderLayout.EAST);
            heightScrollbar.setName("height");
            heightScrollbar.addAdjustmentListener(scrollListener);
            widthScrollbar = new JScrollBar(JScrollBar.HORIZONTAL);
            widthScrollbar.setName("width");
            widthScrollbar.addAdjustmentListener(scrollListener);
            scroll.add(widthScrollbar, BorderLayout.SOUTH);
            imageCanvas = new ImageCanvas(screenImageHandler);
             scroll.add(imageCanvas,BorderLayout.CENTER);
            add("Center",scroll);
           
           
           functionPanel = new FunctionPanel();
           setConfiguration(config, true);
           
           
    
    }
    public void setNewScrollbarValues(int width,int height, Point values)
    {
        setListeners(false);
        widthScrollbar.setMaximum(width);
        heightScrollbar.setMaximum(height);
        widthScrollbar.setValue(values.x);
        heightScrollbar.setValue(values.y);
        setListeners(true);
    }
    public void setListeners(boolean set)
    {
        if (set)
        {
            heightScrollbar.addAdjustmentListener(scrollListener);
            widthScrollbar.addAdjustmentListener(scrollListener);
        } 
        else
        {
            heightScrollbar.removeAdjustmentListener(scrollListener);
            widthScrollbar.removeAdjustmentListener(scrollListener);
        }
    }

    /**
     * Returns the ImageCanvas which contains the GUI of the image.
     * 
     * @return The imageCanvas which contains the image
     * @since 30.04.1999
     */
    public ImageCanvas getImageCanvas()
    {
        return imageCanvas;
    }
    
	public boolean processEvent (DSEvent e)
	{
	    if (e instanceof ChangeOptionsEvent)
	    {
            setConfiguration(((ChangeOptionsEvent)e).getConfig(), false);
	    }
	    return false;
	}
	public void setConfiguration(Hashtable config, boolean init)
	{
        String paintPanelPlacement=null;
        if (config.containsKey("PaintPanelPlacement")) paintPanelPlacement  = (String)config.get("SeparateImagePanelPlacement");
        if (!functionPanel.imagePanelOrientation.equals("None")) remove (functionPanel.paintPanel);
        if (config.containsKey("FunctionPanelPlacement")) 
        {
            if (!init) remove(functionPanel);
            String orient = (String)config.get("FunctionPanelPlacement");
                
            if (!orient.equals("None")) 
            {
                functionPanel.setConfiguration(config,orient);
                add(functionPanel,orient);
            }
            if (!functionPanel.imagePanelOrientation.equals("None"))add(functionPanel.paintPanel,functionPanel.imagePanelOrientation);
            updateUI();
	    }
	}
    
    public class ScrollListener implements AdjustmentListener
    {
        public void adjustmentValueChanged(AdjustmentEvent e)
        {  
            System.out.println("Adjustmentlistne");
            JScrollBar sb = (JScrollBar)e.getSource();
            if (sb.getName().equals("width"))screenImageHandler.setNewImagePartWidth(e.getValue());
            else screenImageHandler.setNewImagePartHeight(e.getValue());
        }
    }


}

/*
 *  CVS Log
 *  $Log: MainImageViewerPanel.java,v $
 *  Revision 1.1.1.1  2000/03/13 14:39:52  kleber
 *  init log for first free release
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
